package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut



__DATA__
M?T5,1@$!`0D```````````(``P`!````P)8$"#0```!0Y````````#0`(``&
M`"@`&0`8``8````T````-(`$"#2`!`C`````P`````4````$`````P```/0`
M``#T@`0(](`$"!4````5````!`````$````!``````````"`!`@`@`0(8MX`
M`&+>```%`````!````$`````X````&`%"`!@!0@8`@``U`8```8`````$```
M`@```!S@```<8`4('&`%"/````#P````!@````0````$````#`$```R!!`@,
M@00(&````!@````$````!````"]L:6)E>&5C+VQD+65L9BYS;RXQ``````@`
M```$`````0```$9R965"4T0`:S4,`&$```!H`````````#L`````````"0``
M``````!=````7````%@``````````````&4`````````10```%L`````````
M-@```#\````Y````#@```#4```!*````/@```$8````````````````````@
M````60```"T````"`````````#````!2````*P```&$```!(````!@```&<`
M``!B````&@`````````I`````````&``````````+````%\`````````3```
M`"<````%````3P```&0````]````00```"0```!5````%P```&8`````````
M+P```!\`````````20````````````````````````!1````1````#,```!7
M````7@```!T```````````````````!6````,0```$````!4````6@````T`
M````````#P````0````````````````````W`````````!X````3````````
M`"H```!C````````````````````````````````````````````````````
M```````````````````````````,````````````````````````````````
M```````````````````````````````1`````P```!@````(````````````
M```+``````````````````````````$`````````````````````````*```
M```````<``````````H````A`````````",`````````````````````````
M```````````````````````````T````````````````````/```````````
M`````````!``````````.```````````````(@`````````;````!P```"8`
M````````0@```"4````````````````````Z````3@```"X`````````````
M`#(````6````30```$,`````````$@`````````5````4P```%``````````
M`````$L````4`````````$<````9`````````````````````````+@#```0
M8`4(!````!$`#P`,`````````"H````2````%P````````!A"0``$@```"D`
M```@8@4(`0```!$`%@!>`P```````#8````2````S`,``+#H!`B2`0``$@`,
M`$`````<8`4(`````!$`\?_"`@`````````````2````W`(```````"8````
M$@```!4#````````6@```!(```!)`````````&,#```2````5P````````"Z
M````$@```&,`````````.@$``!(```#9`P``4/L$"`D````2``P`=````"1B
M!0@$````$0`6`&("```H8@4((````!$`%@!^``````````<'```2````C0``
M`$AB!0@$````$0`6`.H#```0XP0(2@```!(`#`"7`````````,4"```2````
M^`,``'#J!`CU````$@`,`",#````````!0```!(```#S`@```````'0,```2
M````I0```$QB!0@!````$0`6`"D$``#HD@0(`````!(`"@"R``````````8%
M```2````O0````````"-````$@```,H`````````1`$``!(```#8````T&8%
M"`0````1`!8`X``````````B`P``$@```.0"````````30```!(```#L`@``
M```````````2````!`0``+#M!`C<`0``$@`,`.L`````````2````!(````1
M!```8/L$"/4"```2``P`)P0``&#^!`@D````$@`,``X#````````-````!(`
M``"W`@```&`%"`0````1``\`A@,``,"6!`B8````$@`,`$L#````````````
M`!(```##`@`````````````2````+0,````````K````$@```!P#````````
M0````!(````O!```D.\$"`<+```2``P`^@````````#?`P``$@```)("````
M`````````!(```#/`@```````!8````2````H`(```````!W````$@```#P$
M``!PZP0(9````!(`#`#(`@```````(,````2`````P$``$UB!0@!````$0`6
M`#4#````````<P```!(````1`0``_)0$"&8#```2````(0$``%!B!0@$````
M$0`6`($#```88@4(`````!``\?]T`P`````````````2````2`0``.#K!`C0
M`0``$@`,`$T$``"0YP0($0$``!(`#`!,`@``5&(%"`0````1`!8`7P0``*#Z
M!`BO````$@`,`#$!``!88@4(`0```!$`%@`\`0``_/X$"``````2``T`0@$`
M``````!#&P``$@```,0$````````'0```!(```!9`P`````````````2````
M^P(``%QB!0@$````$0`6`%H"````````20```!(```!0`0```````$8````2
M````1@,```````!#````$@```&X#`````````````!(````,`@```````&<&
M```2````=00``!1@!0@$````$0`/`&`!````````/@```!(```!Z`P``&&(%
M"``````0`/'_>P(```````!)````$@```&L!```@804(`````!$`\?^-`P``
MU&8%"``````0`/'_F`(```````!T````$@```($!``!@8@4(`0```!$`%@",
M`0``:&(%"!,````1`!8`&`(```````#5"```$@```(L"`````````````!(`
M``")!```8.,$""@````2``P`FP$```````!]````$@```*8"````````&@``
M`!(```"E!```P)<$"$`````2``P`L@$``'QB!0@$````$0`6`$0#````````
M*P```!(```"R!```4.H$"!\````2``P`N`$``(!B!0@$````$0`6`'0"````
M`````````!(```##`0```````(0"```2````T0$``(1B!0@$````$0`6`%(#
M````````%@```!(```!E`P```````*,````2````UP(`````````````$@``
M`-X!`````````````"`````\`P```````-<````2````\@$````````I````
M$@```(("`````````````!(``````@```````$$````2````$P(````````O
M````$@```+T#```@`@4(ZEL``!$`#@``;&EB<&5R;"YS;P!097)L7V-R;V%K
M`%!E<FQ?<W9?,G!V7V9L86=S`%!,7W!E<FQ?9&5S=')U8W1?;&5V96P`7T19
M3D%-24,`4&5R;%]A=E]S:&EF=`!097)L7VUG7W-E=`!097)L7VYE=UA37V9L
M86=S`%!,7V-O;7!C=@!P97)L7V-O;G-T<G5C=`!03%]P87)S97(`4&5R;%]D
M;W5N=VEN9`!03%]D;U]U;F1U;7``<&5R;%]P87)S90!097)L7VYE=U-6<'8`
M4&5R;%]S=E]S971P=@!E;G9I<F]N`%!E<FQ?;F5W6%,`4&5R;%]S>7-?:6YI
M=#,`<&5R;%]R=6X`4$Q?97AI=%]F;&%G<P!B;V]T7T1Y;F%,;V%D97(`4$Q?
M8W5R<W1A8VMI;F9O`%!,7W1A:6YT960`7V9I;FD`<&5R;%]D97-T<G5C=`!0
M97)L7V=V7V9E=&-H<'8`<&5R;%]A;&QO8P!?1TQ/0D%,7T]&1E-%5%]404),
M15\`4$Q?:6Y?979A;`!03%]M96UO<GE?=W)A<`!097)L7W-A=F5?9&5S=')U
M8W1O<E]X`%!,7V]P`%!,7W1O<%]E;G8`4&5R;%]A=E]F971C:`!03%]E=F%L
M7W)O;W0`7TIV7U)E9VES=&5R0VQA<W-E<P!097)L7W-Y<U]T97)M`%!E<FQ?
M<V%F97-Y<VUA;&QO8P!P97)L7V9R964`;&EB;2YS;RXU`&QI8F-R>7!T+G-O
M+C4`;&EB=71I;"YS;RXX`&QI8F,N<V\N-P!?7VUB7W-B7VQI;6ET`&UE;6UO
M=F4`7U]S=&%C:U]C:&M?9W5A<F0`9V5T<&ED`&UE;6-P>0!R96%D;&EN:P!G
M971U:60`<FUD:7(`<F5A9&1I<@!L<V5E:P!?7W-T86-K7V-H:U]F86EL`%]?
M<')O9VYA;64`;'-T870`<W1R<W1R`%]?97)R;W(`<F5A9`!S=')N8VUP`'-T
M<FYC<'D`=6YL:6YK`')E86QL;V,`7T-U<G)E;G12=6YE3&]C86QE`'-T<G1O
M:P!S=')D=7``;65M<V5T`%]I;FET7W1L<P!O<&5N9&ER`'-T<F-M<`!S<')I
M;G1F`&%T97AI=`!A8V-E<W,`<W1R;&5N`&]P96X`97AE8W9P`&-L;W-E9&ER
M`&UK9&ER`&-L;W-E`%]E9&%T80!?7V)S<U]S=&%R=`!?96YD`"]U<W(O;&]C
M86PO;&EB+W!E<FPU+S4N,3`N,2]M86-H+T-/4D4`;F%M95]L;V%D7VUY7W!A
M<E]P;`!P87)?:6YI=%]E;G8`<&%R7V-U<G)E;G1?97AE8P!P87)?96YV7V-L
M96%N`'!A<E]D:7)N86UE`'!A<E]F:6YD<')O9P!84U]);G1E<FYA;'-?4$%2
M7T)/3U0`>'-?:6YI=`!P87)?;6MT;7!D:7(`<&%R7V-L96%N=7``;6%I;@!P
M87)?<V5T=7!?;&EB<&%T:`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<VEZ95]L
M;V%D7VUY7W!A<E]P;`!84U]);G1E<FYA;'-?4$%27T-,14%24U1!0TL`<&%R
M7V)A<V5N86UE`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`$9"4T1?,2XP
M`````0`````````"``$``0`"``(``@`````````!`````@```````0````$`
M`@`"`````0`````````!`````@`"``$````!``$``@`!``$``@`"``(``@`!
M`````@`"``(``0`"`````@```````0`"``$``0`"``$````!`````@`"``(`
M`@````(``@`"``$````!``(``0`!``(```````(``@`!`````@`!`````@`!
M`````@```````@`"``(````"`````@```````0````$``0!"`@``$```````
M``"P*'H'```"`,T$````````(&(%"`4$```D8@4(!0\``"AB!0@%$```2&(%
M"`42``!,8@4(!1@``$UB!0@%,P``4&(%"`4V``!48@4(!3L``%AB!0@%/0``
M7&(%"`5"``!@8@4(!4\``&AB!0@%4```?&(%"`57``"`8@4(!5H``(1B!0@%
M70``+&$%"`<"```P804(!P,``#1A!0@'!0``.&$%"`<(```\804(!PD``$!A
M!0@'"@``1&$%"`<+``!(804(!PP``$QA!0@'#0``4&$%"`<1``!4804(!Q0`
M`%AA!0@'%@``7&$%"`<7``!@804(!QH``&1A!0@'&P``:&$%"`<<``!L804(
M!QX``'!A!0@''P``=&$%"`<@``!X804(!R(``'QA!0@')0``@&$%"`<H``"$
M804(!RD``(AA!0@'*@``C&$%"`<K``"0804(!RT``)1A!0@'+@``F&$%"`<O
M``"<804(!S```*!A!0@',@``I&$%"`<T``"H804(!S4``*QA!0@'.```L&$%
M"`<_``"T804(!T```+AA!0@'00``O&$%"`=#``#`804(!T0``,1A!0@'10``
MR&$%"`=&``#,804(!T<``-!A!0@'20``U&$%"`=+``#8804(!TX``-QA!0@'
M40``X&$%"`=2``#D804(!U0``.AA!0@'50``[&$%"`=8``#P804(!UL``/1A
M!0@'7```^&$%"`=>``#\804(!U\```!B!0@'8```!&(%"`=B```(8@4(!V,`
M``QB!0@'9```$&(%"`=E```48@4(!V8``(/L#.B@!```Z-MK``"#Q`S#````
M_S4D804(_R4H804(`````/\E+&$%"&@`````Z>#_____)3!A!0AH"````.G0
M_____R4T804(:!````#IP/____\E.&$%"&@8````Z;#_____)3QA!0AH(```
M`.F@_____R5`804(:"@```#ID/____\E1&$%"&@P````Z8#_____)4AA!0AH
M.````.EP_____R5,804(:$````#I8/____\E4&$%"&A(````Z5#_____)51A
M!0AH4````.E`_____R58804(:%@```#I,/____\E7&$%"&A@````Z2#_____
M)6!A!0AH:````.D0_____R5D804(:'````#I`/____\E:&$%"&AX````Z?#^
M____)6QA!0AH@````.G@_O___R5P804(:(@```#IT/[___\E=&$%"&B0````
MZ<#^____)7AA!0AHF````.FP_O___R5\804(:*````#IH/[___\E@&$%"&BH
M````Z9#^____)81A!0AHL````.F`_O___R6(804(:+@```#I</[___\EC&$%
M"&C`````Z6#^____)9!A!0AHR````.E0_O___R64804(:-````#I0/[___\E
MF&$%"&C8````Z3#^____)9QA!0AHX````.D@_O___R6@804(:.@```#I$/[_
M__\EI&$%"&CP````Z0#^____):AA!0AH^````.GP_?___R6L804(:``!``#I
MX/W___\EL&$%"&@(`0``Z=#]____);1A!0AH$`$``.G`_?___R6X804(:!@!
M``#IL/W___\EO&$%"&@@`0``Z:#]____)<!A!0AH*`$``.F0_?___R7$804(
M:#`!``#I@/W___\ER&$%"&@X`0``Z7#]____)<QA!0AH0`$``.E@_?___R70
M804(:$@!``#I4/W___\EU&$%"&A0`0``Z4#]____)=AA!0AH6`$``.DP_?__
M_R7<804(:&`!``#I(/W___\EX&$%"&AH`0``Z1#]____)>1A!0AH<`$``.D`
M_?___R7H804(:'@!``#I\/S___\E[&$%"&B``0``Z>#\____)?!A!0AHB`$`
M`.G0_/___R7T804(:)`!``#IP/S___\E^&$%"&B8`0``Z;#\____)?QA!0AH
MH`$``.F@_/___R4`8@4(:*@!``#ID/S___\E!&(%"&BP`0``Z8#\____)0AB
M!0AHN`$``.EP_/___R4,8@4(:,`!``#I8/S___\E$&(%"&C(`0``Z5#\____
M)11B!0AHT`$``.E`_/__`````%6)Y593@^P0@^3PBUT$B=&-=)T,A=N)-=!F
M!0A^-HM%"(7`="^C`&`%"`^V$(32=".#P`'K"@^V$(/``832=!2`^B]U\:,`
M8`4(#[80@\`!A-)U[+@<8`4(A<!T-(D,).CG_O__QP0D_/X$".C;_O__Z++[
M__^-10B)="0(B40D!(D<).B75```B00DZ!O^___H9OS__^O-D)"0D)"0D)!5
MB>6#[`B`/8AB!0@`=`SK'(/`!*,(8`4(_]*A"&`%"(L0A=)UZ\8%B&(%"`')
MPY!5B>6#[`BA'&$%"(7`=!*X`````(7`=`G'!"0<804(_]#)PY"0D)"0D)"0
MD)"0D)!5B>56BW4(4P^V#HGSA,ET*:&``04(C58!#[8`ZPR)]@^V"H/"`83)
M=!`XP77R#[8*B=.#P@&$R77PB=A;7EW#58GE5U93@>R\"P``B864^?__@\`X
MB86<^?__QX68^?__`````(N5G/G__XL"BU($@X6<^?__"(F%H/G__XNUH/G_
M_XG!B96D^?__B[VD^?__B=,/I,L(,=L/I,(8,=+!X0@)T\'@&('A``#_``^L
M_@@E````_XFUH/G__PG!BX6@^?__P>\("=,/K/X0B;6@^?__P>\0)0#_```)
MP0^VA:#Y__^)O:3Y__^+O9CY__^)S@G&B=@)T(F$_73]__^)M/UP_?__B[VD
M^?__B[6@^?__#ZS^",'O"(GQB?")^XGZ#Z3+"#';#Z3"&#'2P>$("=/!X!B!
MX0``_P`E````_PG!#ZS^"`G3P>\(B?`E`/\```^L_A`)P<'O$(GPB[V8^?__
M)?\```")S@G&B=@)T(FT_7C]__^)A/U\_?__@\<"@_\0B;V8^?__#X75_O__
MC;78_?__C7W8C;0F`````(L.BUX$BT;8BU;<QT8<`````#'(,=HS1J@S5JPS
M1I@S5IR)P8G3#ZS9'P^DP@$!P`G!B4X8@\8(P>L?.?YUP8N5E/G__XN]E/G_
M_XL"BU($B84@]?__BXT@]?__B94D]?__BY64^?__BW<(BW\,BYTD]?__B;4H
M]?__B;TL]?__B[V4^?__BT(0BU(4B86H^?__BX64^?__B96L^?__BW<8BW\<
MBY4D]?__B;6P^?__B[5P_?__B;VT^?__`W`@BX4@]?__@<:9>8):#Z3+!0^L
MT!O!X04)R(N-J/G__\'J&P'&BX4H]?__(XTH]?__]]`CA;#Y__\)R`'&B;6H
M^___QX6L^___`````(N]+/7__XN%*/7__XNU*/7__XN5+/7__XN-(/7__XN=
M)/7__P^L_@(/I,(>BY5\_?__P>`>"<:+A7C]___![P(Q_P&%L/G__Q&5M/G_
M_XN%(/7__XN5)/7__X&%L/G__YEY@EJ#E;3Y__\`(?'WT"'[(X6H^?__]](C
ME:SY__\)P8N%J/O__PG3BY6L^___`8VP^?__$9VT^?__BXVH^___BYVL^___
M#ZS0&\'J&S'2#Z3+!<'A!0G(`86P^?__$96T^?__BY6P^?__BX4@]?__QX5L
M^O__`````,>%O/G__P````")E6CZ__^+E23U__\/K-`"P>H"B86(^?__BX4@
M]?__B96,^?__BY4D]?__BXV(^?__#Z3"'HN5A/W__\'@'@G!BX6`_?__`86H
M^?__BX6H^___$96L^?__@86H^?__F7F"6H.5K/G__P`QTC';]]")C;CY__^+
MC:C[___WTB.-N/G__R'P(?HAVPG:BYUL^O__"<B+C6CZ__\!A:CY__\1E:SY
M__^+A6CZ__^+E6SZ__\/I,L%P>$%#ZS0&PG(P>H;,=(!A:CY__\1E:SY__^+
ME:CY__^+A:C[___'A;S\__\`````QX6T^___`````(F5N/S__XN5K/O__P^L
MT`+!Z@*)A8#Y__^+A:C[__^)E83Y__^+E:S[__^+C8#Y__\/I,(>BY6,_?__
MP>`>"<&+A8C]__^)C;#[__^+C6CZ__\%F7F"6HF%>/G__XN%:/K__X/2``&U
M>/G__XF5?/G___?0$;U\^?__,=(CC;#[__\QVR.%N/G___?2(?HAVPG:BYV\
M_/__"<B+C;C\__\!A7CY__\1E7SY__^+A;C\__^+E;S\__\/I,L%P>$%#ZS0
M&PG(P>H;,=(!A7CY__\1E7SY__^+E7CY__^+O6SZ__^+A6CZ__^+M6CZ__^)
ME3#\__^+E6SZ__^+C;C\___'A33\__\`````#ZS^`@^DPAZ+E93]___!X!X)
MQHN%D/W__\'O`C'_!9EY@EJ)A7#Y__^+A;CY__^#T@`!A7#Y__^+A;C\__^)
ME73Y__^+E;SY__\1E73Y__\QTC';]]+WT"'Q(X6P^___(?LA^@G:BYTT_/__
M"<B+C3#\__\!A7#Y__\1E73Y__^+A3#\__^+E33\__\/I,L%P>$%#ZS0&PG(
MP>H;,=(!A7#Y__\1E73Y__^+E7#Y__^+A;C\___'A0S[__\`````QX7$_/__
M`````(F5"/O__XN5O/S__P^LT`+!Z@*)A6CY__^+A;C\__^)E6SY__^+E;S\
M__^+C6CY__\/I,(>BY6<_?__P>`>"<&+A9C]__^)C<#\__^+C3#\__\%F7F"
M6HF%8/G__XN%L/O__X/2``&%8/G__XN%,/S__XF59/G__XN5M/O__Q&59/G_
M_S'2(XW`_/__,=OWT/?2(?`A^B';"<@)V@&%8/G__Q&59/G__XN5#/O__XN-
M"/O__XN%"/O__XN=#/O__\>%Q/G__P````#'A3S\__\`````#ZS0&P^DRP7!
MX04)R,'J&S'2`85@^?__$95D^?__BY5@^?__BX4P_/__B97`^?__BY4T_/__
M#ZS0`L'J`HF%6/G__XN%,/S__XF57/G__XN5-/S__XN-6/G__P^DPAZ+E:3]
M___!X!X)P8N%H/W__XF-./S__XN-"/O__P69>8):B850^?__BX4(^___@](`
M`;50^?__B954^?__]]`1O53Y__\QTB.-./S__S';(X7`_/__]](A^B';"=H)
MR`&%4/G__Q&55/G__XN-P/G__XN5Q/G__XN%P/G__XN=Q/G__XN]#/O__XNU
M"/O__P^LT!L/I,L%P>$%"<B+C<#Y___!ZALQT@&%4/G__Q&55/G__XN54/G_
M_P^L_@*+A0C[___![P(Q_\>%O/O__P````")E;C[__^+E0S[__\/I,(>BY6L
M_?__P>`>"<:+A:C]__\%F7F"6HF%2/G__XN%P/S__X/2``&%2/G__XN%P/G_
M_XF53/G__XN5Q/S__Q&53/G__S'2,=OWTO?0(?$CA3C\__\A^R'Z"=H)R`&%
M2/G__Q&53/G__XN-N/O__XN5O/O__XN%N/O__XN=O/O__\>%=/K__P````#'
MA<SY__\`````#ZS0&P^DRP7!X04)R,'J&S'2`85(^?__$95,^?__BY5(^?__
MBX7`^?__B95P^O__BY7$^?__#ZS0`L'J`HF%0/G__XN%P/G__XF51/G__XN5
MQ/G__XN-0/G__P^DPAZ+E;3]___!X!X)P8N%L/W__XF-R/G__P69>8):B84X
M^?__@](`BX4X_/__`84X^?__B94\^?__BY4\_/__$94\^?__,=*+A;C[__\Q
MV_?2BXVX^___(?HAVR.-R/G__PG:BYUT^O__]]`A\`G(BXUP^O__`84X^?__
M$94\^?__BX5P^O__BY5T^O__#Z3+!<'A!<>%S/S__P````#'A<3[__\`````
M#ZS0&PG(P>H;,=(!A3CY__\1E3SY__^+E3CY__^+A;C[__^)E<C\__^+E;S[
M__\/K-`"P>H"B84P^?__BX6X^___B94T^?__BY6\^___BXTP^?__#Z3"'HN5
MO/W__\'@'@G!BX6X_?__B8W`^___!9EY@EJ#T@")A2CY__^)E2SY__^+A7#Z
M__\!M2CY__^+C7#Z__\1O2SY__\QTB.-P/O___?0(X7(^?__,=OWTB';B[5P
M^O__(?J+O73Z__\)V@G(BYW,_/__`84H^?__$94L^?__BXW(_/__BY7,_/__
MBX7(_/__QX5$_/__``````^DRP7!X04/K-`;"<C!ZALQT@&%*/G__Q&5+/G_
M_XN5*/G__P^L_@*+A7#Z___![P(Q_XF50/S__XN5=/K__P^DPAZ+E<3]___!
MX!X)QHN%P/W__P69>8):@](`B84@^?__B94D^?__BX7(^?__`84@^?__BX7(
M_/__BXW(_/__BY7,^?__$94D^?__,=+WT#';(X7`^___]](A\2'[(?H)V@G(
MBYU$_/__`84@^?__$94D^?__BXU`_/__BY5$_/__BX5`_/__QX44^___````
M``^DRP7!X04/K-`;"<C!ZALQT@&%(/G__Q&5)/G__XN5(/G__XN%R/S__XF5
M$/O__XN5S/S__P^LT`+!Z@*)A1CY__^+A<C\__^)E1SY__^+E<S\__^+C1CY
M__\/I,(>P>`>"<&)C=#\__^+A<C]__^+E<S]__^+C4#\___'A=3\__\`````
M!9EY@EJ)A1#Y__^+A<#[__^#T@`!A1#Y__^+A4#\__^)E13Y__^+E<3[__\1
ME13Y__\QTB.-T/S__S';]]#WTB'P(?HAVPG(BXT0^___"=J+G13[__\!A1#Y
M__\1E13Y__^+A1#[__^+E13[__\/I,L%P>$%QX74^?__``````^LT!L)R,'J
M&S'2`840^?__$944^?__BY40^?__BX5`_/__B970^?__BY5$_/__#ZS0`L'J
M`HF%"/G__XN%0/S__XF5#/G__XN51/S__XN-"/G__\>%3/S__P`````/I,(>
MBY74_?__P>`>"<&+A=#]__^)C4C\__^+C1#[__\%F7F"6HF%`/G__XN%$/O_
M_X/2``&U`/G__XF5!/G___?0$;T$^?__,=(CC4C\__\QVR.%T/S___?2(?HA
MVPG:BYW4^?__"<B+C=#Y__\!A0#Y__\1E03Y__^+A=#Y__^+E=3Y__\/I,L%
MP>$%#ZS0&PG(P>H;,=(!A0#Y__\1E03Y__^+E0#Y__^)E<C[__^+O13[__^+
MA1#[__^+M1#[__^+E13[__^+C=#Y___'A<S[__\`````#ZS^`@^DPAZ+E=S]
M___!X!X)QHN%V/W__\'O`C'_!9EY@EJ)A?CX__^+A=#\__^#T@`!A?CX__^+
MA=#Y__^)E?SX__^+E=3\__\1E?SX__\QTC';]]+WT"'Q(X5(_/__(?LA^@G:
MBYW,^___"<B+C<C[__\!A?CX__\1E?SX__^+A<C[__^+E<S[__\/I,L%P>$%
M#ZS0&PG(P>H;,=(!A?CX__\1E?SX__^+E?CX__^)E7CZ__^+E=3Y__^+A=#Y
M___'A7SZ__\`````QX7<^?__``````^LT`+!Z@*)A?#X__^+A=#Y__^)E?3X
M__^+E=3Y__^+C?#X__\/I,(>BY7D_?__P>`>"<&+A>#]__^)C=CY__^+C<C[
M__\%F7F"6HF%Z/C__XN%2/S__X/2``&%Z/C__XN%R/O__XF5[/C__XN53/S_
M_Q&5[/C__S'2(XW8^?__,=OWT/?2(?`A^B';"<B+C7CZ__\)VHN=?/K__P&%
MZ/C__Q&5[/C__XN%>/K__XN5?/K__P^DRP7!X04/K-`;"<C!ZALQT@&%Z/C_
M_Q&5[/C__XN5Z/C__XN%R/O__\>%W/S__P````#'A=3[__\`````B978_/__
MBY7,^___#ZS0`L'J`HF%X/C__XN%R/O__XF5Y/C__XN5S/O__XN-X/C__P^D
MPAZ+E>S]___!X!X)P8N%Z/W__XF-T/O__XN->/K__P69>8):B878^/__BX5X
M^O__@](``;78^/__B97<^/__]]`1O=SX__\QTB.-T/O__S';(X78^?__]](A
M^B';"=J+G=S\__\)R(N-V/S__P&%V/C__Q&5W/C__XN%V/S__XN5W/S__P^D
MRP7!X04/K-`;"<C!ZALQT@&%V/C__Q&5W/C__XN5V/C__XN]?/K__XN%>/K_
M_XNU>/K__XF54/S__XN5?/K__XN-V/S__\>%5/S__P`````/K/X"#Z3"'HN5
M]/W__\'@'@G&BX7P_?__P>\",?\%F7F"6HF%T/C__XN%V/G__X/2``&%T/C_
M_XN%V/S__XF5U/C__XN5W/G__Q&5U/C__S'2,=OWTO?0(?$CA=#[__\A^R'Z
M"=J+G53\__\)R(N-4/S__P&%T/C__Q&5U/C__XN%4/S__XN55/S__P^DRP7!
MX04/K-`;"<C!ZALQT@&%T/C__Q&5U/C__XN5T/C__XN%V/S__\>%'/O__P``
M``#'A>3\__\`````B948^___BY7<_/__#ZS0`L'J`HF%R/C__XN%V/S__XF5
MS/C__XN5W/S__XN-R/C__P^DPAZ+E?S]___!X!X)P8N%^/W__XF-X/S__XN-
M4/S__P69>8):B87`^/__BX70^___@](``87`^/__BX50_/__B97$^/__BY74
M^___$97$^/__,=(CC>#\__\QV_?0]](A\"'Z(=L)R`G:`87`^/__$97$^/__
MBY4<^___BXT8^___BX48^___BYT<^___QX7D^?__`````,>%7/S__P`````/
MK-`;#Z3+!<'A!0G(P>H;,=(!A<#X__\1E<3X__^+E<#X__^+A5#\__^)E>#Y
M__^+E53\__\/K-`"P>H"B86X^/__BX50_/__B96\^/__BY54_/__BXVX^/__
M#Z3"'HN5!/[__\'@'@G!BX4`_O__B8U8_/__BXT8^___!9EY@EJ)A;#X__^+
MA1C[__^#T@`!M;#X__^)E;3X___WT!&]M/C__S'2(XU8_/__,=LCA>#\___W
MTB'Z(=L)V@G(`86P^/__$96T^/__BXW@^?__BY7D^?__BX7@^?__BYWD^?__
MQX7<^___`````,>%)/O__P`````/K-`;#Z3+!8N='/O__\'A!0G(BXT8^___
MP>H;,=(!A;#X__\1E;3X__^+E;#X__\/K-D"BX48^___B<Z+C>#Y___!ZP*+
MG=S[__^)E=C[__^+E1S[__\/I,(>BY7<^___P>`>"<:+A>#Y__^)M2#[__^+
MM0C^___WT('&F7F"6@.UX/S__R.-(/O__R.%6/S__PG(BXW8^___`<:+A=C[
M__\/I,L%#ZS0&\'A!0G(P>H;`<:)M8#Z__^+G>3Y__^+A>#Y__^+C>#Y__^+
ME>3Y__^+M1#^___'A83Z__\`````B[W<^___#ZS9`@^DPAZ+E83Z___!X!X)
MP8N%(/O__\'K`C';@<:AZ]EN`[58_/__,<@SA=C[___'A>S\__\``````<:+
MA8#Z__\/K-`;P>H;B848]?__BX6`^O__B94<]?__BY6$^O__#Z3"!<'@!8F%
MJ/C__XN%&/7__PN%J/C__XF5K/C__XN5W/O__P'&BX78^___B;7H_/__B[78
M^___#Z3"'HN5'/[__P^L_@+!X!X)QHN%&/[__\'O`C'_!:'KV6Z)A:#X__^#
MT@"+A2#[__\!A:#X__^)\(F5I/C__XN5)/O__Q&5I/C__XGZ,=HQR#':,X6`
M^O__`86@^/__$96D^/__BX7H_/__BY7L_/__QX5D_/__``````^LT!O!ZAN)
MA1#U__^+A>C\__^)E13U__^+E>S\__\/I,(%P>`%B868^/__BX40]?__"X68
M^/__B96<^/__,=(!A:#X__\1E:3X__^+E:#X__^+A8#Z__^)E6#\__^+E83Z
M__\/K-`"P>H"B860^/__BX6`^O__B964^/__BY6$^O__#Z3"'HF5#/7__XN5
MD/C__\'@'HF%"/7__PG"B96(^/__BX64^/__"X4,]?__B96(^O__BY4D_O__
MQX6,^O__`````(F%C/C__XN%(/[__\>%+/O__P`````%H>O9;HF%@/C__XN%
MB/K__X/2``&-@/C__XN-8/S__XF5A/C__Q&=A/C__S'2,?HQ\#':BYUD_/__
M,X7H_/__`86`^/__$96$^/__BX5@_/__#Z3+!8N59/S__\'A!8N=[/S__P^L
MT!L)R(N-Z/S__\'J&S'2`86`^/__$96$^/__BY6`^/__#ZS9`HN%Z/S__\'K
M`C';B94H^___BY7L_/__#Z3"'HN5+/[__\'@'@G!BX4H_O__!:'KV6Z)A7CX
M__^+A8CZ__^#T@`!M7CX__^+M2C[__^)E7SX__\1O7SX__\QTC':,<B+O2S[
M__\SA6#\__\QV@&%>/C__Q&5?/C__XN%*/O__P^D]P6+E2S[___!Y@6+O63\
M___'A>SY__\`````#ZS0&PGPB[5@_/__P>H;,=(!A7CX__\1E7SX__^+E7CX
M__\/K/X"BX5@_/__P>\",?^)E>CY__^+E63\__\/I,(>BY4T_O__P>`>"<:+
MA3#^__\%H>O9;H/2`(F%</C__XN%B/K__XF5=/C__XN5C/K__P&%</C__XGP
M$95T^/__B?HQVC'(,=HSA2C[__\!A7#X__\1E73X__^+A>CY__^+E>SY___'
MA>3[__\`````#ZS0&\'J&XF%`/7__XN%Z/G__XF5!/7__XN5[/G__P^DP@7!
MX`6)A6CX__^+A0#U__\+A6CX__^)E6SX__\QT@&%</C__Q&5=/C__XN5</C_
M_XN%*/O__XF5X/O__XN5+/O__P^LT`+!Z@*)A6#X__^+A2C[__^)E63X__^+
ME2S[__\/I,(>P>`>B87X]/__B97\]/__BY5@^/__QX4T^___``````G"BX5D
M^/__"X7\]/__B94P^___B958^/__BY4\_O__B85<^/__BX4X_O__!:'KV6Z)
MA5#X__^+A3#[__^#T@`!C5#X__^+C>#[__^)E53X__\1G53X__\QTC'Z,?`Q
MVHN=Y/O__S.%Z/G__P&%4/C__Q&55/C__XN%X/O__P^DRP6+E>3[___!X04/
MK-`;"<C!ZALQT@&%4/C__Q&55/C__XN54/C__XF5D/K__XN=[/G__XN%Z/G_
M_XN-Z/G__XN5[/G__\>%E/K__P````#'A?3\__\`````#ZS9`@^DPAZ+E43^
M___!X!X)P8N%0/[__\'K`C';!:'KV6Z)A4CX__^+A3#[__^#T@`!M4CX__^+
MM9#Z__^)E4SX__\1O4SX__\QTC':,<B+O93Z__\SA>#[__\QV@&%2/C__Q&5
M3/C__XN%D/K__P^D]P6+E93Z___!Y@6+O>3[__\/K-`;"?"+M>#[___!ZALQ
MT@&%2/C__Q&53/C__XN52/C__P^L_@*+A>#[___![P(Q_XF5\/S__XN5Y/O_
M_P^DPAZ+E4S^___!X!X)QHN%2/[__P6AZ]ENB85`^/__@](`BX4P^___`85`
M^/__B?")E43X__^+E33[__\1E43X__^)^C':,<@QVC.%D/K__P&%0/C__Q&5
M1/C__XN%\/S__XN5]/S__\>%;/S__P`````/K-`;P>H;B87P]/__BX7P_/__
MB97T]/__BY7T_/__#Z3"!<'@!8F%./C__XN%\/3__PN%./C__XF5//C__S'2
M`85`^/__$95$^/__BY5`^/__BX60^O__B95H_/__BY64^O__#ZS0`L'J`HF%
M,/C__XN%D/K__XF5-/C__XN5E/K__\>%G/K__P`````/I,(>B97L]/__BY4P
M^/__P>`>B87H]/__"<*+A33X__\+A>ST__^)E9CZ__^)E2CX__^+E53^__^)
MA2SX__^+A5#^__\%H>O9;HF%(/C__XN%F/K__X/2``&-(/C__XN-:/S__XF5
M)/C__Q&=)/C__S'2,?HQ\#':BYUL_/__,X7P_/__`84@^/__$94D^/__BX5H
M_/__#Z3+!8N5;/S__\'A!0^LT!L)R,'J&S'2`84@^/__$94D^/__BY4@^/__
MBYWT_/__BX7P_/__BXWP_/__B94X^___BY7T_/__QX4\^___``````^LV0(/
MI,(>BY5<_O__P>`>"<&+A5C^___!ZP(QVP6AZ]ENB848^/__BX68^O__@](`
M`;48^/__B[4X^___B94<^/__$;T<^/__,=(QVC'(B[T\^___,X5H_/__,=H!
MA1CX__\1E1SX__^+A3C[__\/I/<%BY4\^___P>8%#ZS0&PGPP>H;,=(!A1CX
M__\1E1SX__^+E1CX__^)E?#Y__^+O6S\__^+A6C\__^+M6C\__^+E6S\___'
MA?3Y__\`````#ZS^`@^DPAZ+E63^___!X!X)QHN%8/[__\'O`C'_!:'KV6Z)
MA1#X__^#T@"+A9CZ__\!A1#X__^)\(F5%/C__XN5G/K__Q&5%/C__XGZ,=HQ
MR#':,X4X^___`840^/__$944^/__BX7P^?__BY7T^?__#ZS0&\'J&XF%X/3_
M_XN%\/G__XF5Y/3__XN5]/G__P^DP@7!X`6)A0CX__^+A>#T__\+A0CX__^)
ME0SX__\QT@&%$/C__Q&5%/C__XN5$/C__XN%./O__\>%[/O__P````#'A43[
M__\`````B97H^___BY4\^___#ZS0`L'J`HF%`/C__XN%./O__XF5!/C__XN5
M//O__P^DPAZ)E=ST__^+E0#X___!X!Z)A=CT__\)PHN%!/C__PN%W/3__XF5
M0/O__XF5^/?__XN5;/[__XF%_/?__XN%:/[__P6AZ]ENB87P]___BX5`^___
M@](``8WP]___B97T]___$9WT]___,=(Q^C'P,=HSA?#Y__\!A?#W__\1E?3W
M__^+E>S[__^+C>C[__^+A>C[__^+G>S[___'A:3Z__\`````#ZS0&P^DRP6+
MG?3Y___!X04)R(N-\/G__\'J&S'2`87P]___$97T]___BY7P]___#ZS9`HN%
M\/G__\'K`C';B96@^O__BY7T^?__#Z3"'HN5=/[__\'@'@G!BX5P_O__!:'K
MV6Z)A>CW__^+A4#[__^#T@`!M>CW__^+M:#Z__^)E>SW__\1O>SW__\QTC':
M,<B+O:3Z__\SA>C[__\QV@&%Z/?__Q&5[/?__XN%H/K__P^D]P6+E:3Z___!
MY@4/K-`;"?#!ZALQT@&%Z/?__Q&5[/?__XN5Z/?__XN][/O__XN%Z/O__XNU
MZ/O__XF5^/S__XN5[/O__\>%_/S__P`````/K/X"#Z3"'HN5?/[__\'@'@G&
MBX5X_O__P>\",?\%H>O9;HF%X/?__X/2`(N%0/O__P&%X/?__XGPB97D]___
MBY5$^___$97D]___B?HQVC'(,=HSA:#Z__\!A>#W__\1E>3W__^+A?C\__^+
ME?S\__\/K-`;P>H;B870]/__BX7X_/__B974]/__BY7\_/__#Z3"!<'@!8F%
MV/?__XN%T/3__PN%V/?__XF5W/?__S'2`87@]___$97D]___BY7@]___BX6@
M^O__QX5T_/__`````,>%K/K__P````")E7#\__^+E:3Z__\/K-`"P>H"B870
M]___BX6@^O__B974]___BY6D^O__#Z3"'HF5S/3__XN5T/?__\'@'HF%R/3_
M_PG"BX74]___"X7,]/__B97(]___B96H^O__BY6$_O__B87,]___BX6`_O__
M!:'KV6Z)A<#W__^#T@`!C<#W__^)E<3W__\1G<3W__\QTHN%J/K__S'Z,=J+
MC7#\__^+G73\___'A4S[__\`````,?`SA?C\__\!A<#W__\1E<3W__^+A7#\
M__\/I,L%BY5T_/__P>$%BYW\_/__#ZS0&PG(BXWX_/__P>H;,=(!A<#W__\1
ME<3W__^+E<#W__\/K-D"BX7X_/__P>L",=N)E4C[__^+E?S\__\/I,(>BY6,
M_O__P>`>"<&+A8C^__\%H>O9;HF%N/?__XN%J/K__X/2``&UN/?__XF5O/?_
M_Q&]O/?__S'2,=HQR#':,X5P_/__`86X]___$96\]___B[5(^___BY5,^___
MBX5(^___B[U,^___QX7\^?__``````^LT!L/I/<%B[UT_/__P>8%"?"+M7#\
M___!ZALQT@&%N/?__Q&5O/?__XN5N/?__P^L_@*+A7#\___![P(Q_XF5^/G_
M_XN5=/S__P^DPAZ+E93^___!X!X)QHN%D/[__P6AZ]ENB86P]___@](`BX6H
M^O__`86P]___B?")E;3W__^+E:SZ__\1E;3W__^)^C':,<@QVC.%2/O__P&%
ML/?__Q&5M/?__XN5_/G__XN%^/G__\>%]/O__P`````/K-`;P>H;B87`]/__
MBX7X^?__B97$]/__BY7\^?__#Z3"!<'@!8F%J/?__XN%P/3__PN%J/?__XF5
MK/?__S'2`86P]___$96T]___BY6P]___BX5(^___B97P^___BY5,^___#ZS0
M`L'J`HF%H/?__XN%2/O__XF5I/?__XN53/O__P^DPAZ)E;ST__^+E:#W___!
MX!Z)A;CT__\)PHN%I/?__PN%O/3__XF5F/?__XF54/O__XF%G/?__\>%5/O_
M_P````"+A9C^__^+E9S^___'A;3Z__\`````!:'KV6Z)A9#W__^+A5#[__^#
MT@`!C9#W__^+C?#[__^)E93W__\1G93W__\QTC'Z,?`QVHN=]/O__S.%^/G_
M_P&%D/?__Q&5E/?__XN%\/O__P^DRP6+E?3[___!X06+G?SY__\/K-`;"<B+
MC?CY___!ZALQT@&%D/?__Q&5E/?__XN5D/?__P^LV0*+A?CY___!ZP(QVXF5
ML/K__XN5_/G__P^DPAZ+E:3^___!X!X)P8N%H/[__P6AZ]ENB86(]___BX50
M^___@](``;6(]___B[6P^O__B96,]___$;V,]___,=(QVC'(B[VT^O__,X7P
M^___,=H!A8CW__\1E8SW__^+A;#Z__\/I/<%BY6T^O__P>8%B[WT^___QX4$
M_?__``````^LT!L)\(NU\/O__\'J&S'2`86(]___$96,]___BY6(]___#ZS^
M`HN%\/O__\'O`C'_B94`_?__BY7T^___#Z3"'HN5K/[__\'@'@G&BX6H_O__
M!:'KV6Z#T@")A8#W__^+A5#[__^)E83W__^+E53[__\!A8#W__^)\!&5A/?_
M_XGZ,=HQR#':,X6P^O__`86`]___$96$]___BX4`_?__BY4$_?__QX5\_/__
M``````^LT!O!ZAN)A;#T__^+A0#]__^)E;3T__^+E03]__\/I,(%P>`%B85X
M]___BX6P]/__"X5X]___B95\]___,=(!A8#W__\1E83W__^+E8#W__^+A;#Z
M__^)E7C\__^+E;3Z__\/K-`"P>H"B85P]___BX6P^O__B95T]___BY6T^O__
M#Z3"'L'@'HF%J/3__XF5K/3__XN5</?__\>%O/K__P`````)PHN%=/?__PN%
MK/3__XF5N/K__XF5:/?__XN5M/[__XF%;/?__XN%L/[__P7<O!N/B85@]___
MBX6X^O__@](``8U@]___BXVX^O__B95D]___$9UD]___"?`QTB.%`/W__PGZ
M(?$AVB'["=H)R(N=?/S__P&%8/?__Q&59/?__XN->/S__XN5?/S__XN%>/S_
M_P^DRP7!X04/K-`;"<C!ZALQT@&%8/?__Q&59/?__XN58/?__XF56/O__XN5
M!/W__XN%`/W__\>%7/O__P````#'A0S]__\`````#ZS0`L'J`HF%6/?__XN%
M`/W__XF57/?__XN5!/W__XN-6/?__P^DPAZ+E;S^___!X!X)P8N%N/[__XF-
M"/W__P7<O!N/B850]___@](`B<@!M5#W__^)E53W__\1O53W__\QTB.-N/K_
M_PG2"X6X^O__,=LCA7C\__\A^B';"=J+G5S[__\)R(N-6/O__P&%4/?__Q&5
M5/?__XN%6/O__XN57/O__P^DRP7!X04/K-`;"<C!ZALQT@&%4/?__Q&55/?_
M_XN54/?__XN]?/S__XN%>/S__XNU>/S__XF5`/K__XN5?/S__XN-"/W__\>%
M!/K__P`````/K/X"#Z3"'HN5Q/[__\'@'@G&BX7`_O__P>\",?\%W+P;CXF%
M2/?__XN%N/K__X/2``&%2/?__XN%"/W__XF53/?__XN5O/K__Q&53/?__S'2
M"?HQVPGP(?$CA5C[__\A^R'Z"=J+G03Z__\)R(N-`/K__P&%2/?__Q&53/?_
M_XN%`/K__XN5!/K__P^DRP7!X04/K-`;"<C!ZALQT@&%2/?__Q&53/?__XN5
M2/?__XN%6/O__\>%_/O__P````#'A63[__\`````B97X^___BY5<^___#ZS0
M`L'J`HF%0/?__XN%6/O__XF51/?__XN57/O__XN-0/?__P^DPAZ+E<S^___!
MX!X)P8N%R/[__XF-8/O__P7<O!N/B84X]___@](`BX4(_?__`84X]___B<B)
ME3SW__^+E0S]__\1E3SW__\)\#'2,=LCA0#Z__\)^B'Q(?LA^@G:"<B+G?S[
M__\!A3CW__\1E3SW__^+C?C[__^+E?S[__^+A?C[__\/I,L%P>$%#ZS0&PG(
MP>H;,=(!A3CW__\1E3SW__^+E3CW__^+A0#Z___'A<3Z__\`````QX4,^O__
M`````(F5P/K__XN5!/K__P^LT`+!Z@*)A3#W__^+A0#Z__^)E33W__^+E03Z
M__^+C3#W__\/I,(>BY74_O__P>`>"<&+A=#^__^)C0CZ__\%W+P;CXF%*/?_
M_X/2`(G(`;4H]___B94L]___$;TL]___,=(CC6#[__\)T@N%8/O__S';(X7X
M^___(?HAVPG:BYW$^O__"<B+C<#Z__\!A2CW__\1E2SW__^+A<#Z__^+E<3Z
M__\/I,L%P>$%#ZS0&PG(P>H;,=(!A2CW__\1E2SW__^+E2CW__^+O?S[__^+
MA?C[__^+M?C[__^)E1#]__^+E?S[__^+C0CZ___'A13]__\`````#ZS^`@^D
MPAZ+E=S^___!X!X)QHN%V/[__\'O`C'_!=R\&X^)A2#W__^+A6#[__^#T@`!
MA2#W__^+A0CZ__^)E23W__^+E63[__\1E23W__\QT@GZ,=L)\"'Q(X7`^O__
M(?LA^@G:BYT4_?__"<B+C1#]__\!A2#W__\1E23W__^+A1#]__^+E13]__\/
MI,L%P>$%#ZS0&PG(P>H;,=(!A2#W__\1E23W__^+E2#W__^+A<#Z___'A83\
M__\`````QX7,^O__`````(F5@/S__XN5Q/K__P^LT`+!Z@*)A1CW__^+A<#Z
M__^)E1SW__^+E<3Z__^+C1CW__\/I,(>BY7D_O__P>`>"<&+A>#^__^)C<CZ
M__\%W+P;CXF%$/?__X/2`(N%"/K__P&%$/?__XG(B944]___BY4,^O__$944
M]___"?`QTC';(X40_?__"?HA\2'[(?H)V@G(BYV$_/__`840]___$944]___
MBXV`_/__BY6$_/__BX6`_/__#Z3+!<'A!0^LT!L)R,'J&S'2`840]___$944
M]___BY40]___BX40_?__QX5L^___`````,>%'/W__P````")E6C[__^+E13]
M__\/K-`"P>H"B84(]___BX40_?__B94,]___BY44_?__BXT(]___#Z3"'HN5
M[/[__\'@'@G!BX7H_O__B8T8_?__!=R\&X^)A0#W__^#T@")R`&U`/?__XF5
M!/?__Q&]!/?__S'2(XW(^O__"=(+A<CZ__\QVR.%@/S__R'Z(=L)VHN=;/O_
M_PG(BXUH^___`84`]___$94$]___BX5H^___BY5L^___#Z3+!<'A!0^LT!L)
MR,'J&S'2`84`]___$94$]___BY4`]___B[V$_/__BX6`_/__B[6`_/__B940
M^O__BY6$_/__BXT8_?__QX44^O__``````^L_@(/I,(>BY7T_O__P>`>"<:+
MA?#^___![P(Q_P7<O!N/B87X]O__BX7(^O__@](``87X]O__BX48_?__B97\
M]O__BY7,^O__$97\]O__,=()^C';"?`A\2.%:/O__R'[(?H)VHN=%/K__PG(
MBXT0^O__`87X]O__$97\]O__BX40^O__BY44^O__#Z3+!<'A!0^LT!L)R,'J
M&S'2`87X]O__$97\]O__BY7X]O__BX5H^___QX4$_/__`````,>%=/O__P``
M``")E0#\__^+E6S[__\/K-`"P>H"B87P]O__BX5H^___B97T]O__BY5L^___
MBXWP]O__#Z3"'HN5_/[__\'@'@G!BX7X_O__B8UP^___!=R\&X^)A>CV__^#
MT@"+A1C]__\!A>CV__^)R(F5[/;__XN5'/W__Q&5[/;__PGP,=(QVR.%$/K_
M_PGZ(?$A^R'Z"=H)R(N=!/S__P&%Z/;__Q&5[/;__XN-`/S__XN5!/S__XN%
M`/S__P^DRP7!X04/K-`;"<C!ZALQT@&%Z/;__Q&5[/;__XN5Z/;__XN%$/K_
M_\>%U/K__P````#'A1SZ__\`````B970^O__BY44^O__#ZS0`L'J`HF%X/;_
M_XN%$/K__XF5Y/;__XN5%/K__XN-X/;__P^DPAZ+E03____!X!X)P8N%`/__
M_XF-&/K__P7<O!N/B878]O__@](`B<@!M=CV__^)E=SV__\1O=SV__\QTB.-
M</O__PG2"X5P^___,=LCA0#\__\A^B';"=J+G=3Z__\)R(N-T/K__P&%V/;_
M_Q&5W/;__XN%T/K__XN5U/K__P^DRP7!X04/K-`;"<C!ZALQT@&%V/;__Q&5
MW/;__XN5V/;__XN]!/S__XN%`/S__XNU`/S__XF5(/W__XN5!/S__XN-&/K_
M_\>%)/W__P`````/K/X"#Z3"'HN5#/___\'@'@G&BX4(____P>\",?\%W+P;
MCXF%T/;__XN%</O__X/2``&%T/;__XN%&/K__XF5U/;__XN5=/O__Q&5U/;_
M_S'2"?HQVPGP(?$CA=#Z__\A^R'Z"=J+G23]__\)R(N-(/W__P&%T/;__Q&5
MU/;__XN%(/W__XN5)/W__P^DRP7!X04/K-`;"<C!ZALQT@&%T/;__Q&5U/;_
M_XN5T/;__XN%T/K__\>%C/S__P````#'A=SZ__\`````B96(_/__BY74^O__
M#ZS0`L'J`HF%R/;__XN%T/K__XF5S/;__XN5U/K__XN-R/;__P^DPAZ+E13_
M___!X!X)P8N%$/___XF-V/K__P7<O!N/B87`]O__@](`BX48^O__`87`]O__
MB<B)E<3V__^+E1SZ__\1E<3V__\)\#'2,=LCA2#]__\)^B'Q(?LA^@G:"<B+
MG8S\__\!A<#V__\1E<3V__^+C8C\__^+E8S\__^+A8C\__\/I,L%P>$%#ZS0
M&PG(P>H;,=(!A<#V__\1E<3V__^+E<#V__^+A2#]___'A7S[__\`````QX4L
M_?__`````(F5>/O__XN5)/W__P^LT`+!Z@*)A;CV__^+A2#]__^)E;SV__^+
ME23]__^+C;CV__\/I,(>BY4<____P>`>"<&+A1C___^)C2C]__\%W+P;CXF%
ML/;__X/2`(G(`;6P]O__B96T]O__$;VT]O__,=(CC=CZ__\)T@N%V/K__S';
M(X6(_/__(?HAVPG:BYU\^___"<B+C7C[__\!A;#V__\1E;3V__^+A7C[__^+
ME7S[__\/I,L%P>$%#ZS0&PG(P>H;,=(!A;#V__\1E;3V__^+E;#V__^+O8S\
M__^+A8C\__^+M8C\__^)E2#Z__^+E8S\__^+C2C]___'A23Z__\`````#ZS^
M`@^DPAZ+E23____!X!X)QHN%(/___\'O`C'_!=R\&X^)A:CV__^+A=CZ__^#
MT@`!A:CV__^+A2C]__^)E:SV__^+E=SZ__\1E:SV__\QT@GZ,=L)\"'Q(X5X
M^___(?LA^@G:BYTD^O__"<B+C2#Z__\!A:CV__\1E:SV__^+A2#Z__^+E23Z
M__\/I,L%P>$%#ZS0&PG(P>H;,=(!A:CV__\1E:SV__^+E:CV__^+A7C[___'
MA0S\__\`````QX6$^___`````(F5"/S__XN5?/O__P^LT`+!Z@*)A:#V__^+
MA7C[__^)E:3V__^+E7S[__^+C:#V__\/I,(>BY4L____P>`>"<&+A2C___^)
MC8#[__\%W+P;CXF%F/;__X/2`(N%*/W__P&%F/;__XG(B96<]O__BY4L_?__
M$96<]O__"?`QTC';(X4@^O__"?HA\2'[(?H)V@G(BYT,_/__`868]O__$96<
M]O__BXT(_/__BY4,_/__BX4(_/__#Z3+!<'A!0^LT!L)R,'J&S'2`868]O__
M$96<]O__BY68]O__BX4@^O__QX4L^O__`````(N=+/K__\>%Y/K__P````")
ME>#Z__^+E23Z__\/K-`"P>H"B860]O__BX4@^O__B964]O__BY4D^O__BXV0
M]O__#Z3"'HN5-/___\'@'@G!BX4P____B8TH^O__!=R\&X^#T@")A8CV__^)
MR`&UB/;__XF5C/;__XN5+/K__Q&]C/;__R.-@/O__R.=A/O__PN%@/O__PN5
MA/O__R.%"/S__R.5#/S__PG("=H!A8CV__\1E8SV__^+C>#Z__^+E>3Z__^+
MA>#Z__^+G>3Z__^+O0S\__^+M0C\__\/K-`;#Z3+!8N=+/K__\'A!0G(BXTH
M^O__P>H;,=(!A8CV__\1E8SV__^+E8CV__\/K/X"BX4(_/__P>\",?_'A33]
M__\`````B94P_?__BY4,_/__#Z3"'HN5//___\'@'@G&BX4X____!=R\&X^)
MA8#V__^#T@"+A8#[__\!A8#V__^+A2CZ__^)E83V__^+E83[__\1E83V__\A
M\8N5+/K__R'["?`CA>#Z__\)^B.5Y/K__PG("=H!A8#V__\1E83V__^+C3#]
M__^+E33]__^+A3#]__^+G33]___'A93\__\`````QX7L^O__``````^LT!L/
MI,L%P>$%"<C!ZALQT@&%@/;__Q&5A/;__XN5@/;__XN%X/K__XF5D/S__XN5
MY/K__P^LT`+!Z@*)A7CV__^+A>#Z__^)E7SV__^+E>3Z__^+C7CV__\/I,(>
MBY5$____P>`>"<&+A4#___^)C>CZ__\%W+P;CXF%</;__X/2`(N%*/K__P&%
M</;__XG(B95T]O__BY4L^O__$95T]O__"?`QTC';(X4P_?__"?HA\2'[(?H)
MV@G(BYV4_/__`85P]O__$95T]O__BXV0_/__BY64_/__BX60_/__QX6,^___
M``````^DRP7!X04/K-`;"<C!ZALQT@&%</;__Q&5=/;__XN5</;__XN%,/W_
M_\>%//W__P````")E8C[__^+E33]__\/K-`"P>H"B85H]O__BX4P_?__B95L
M]O__BY4T_?__BXUH]O__#Z3"'HN53/___\'@'@G!BX5(____B8TX_?__!=R\
M&X^)A6#V__^#T@")R`&U8/;__XF59/;__Q&]9/;__S'2(XWH^O__"=(+A>CZ
M__\QVR.%D/S__R'Z(=N+M5#___\)VHN=C/O__PG(BXV(^___`85@]O__$95D
M]O__BX6(^___BY6,^___#Z3+!<'A!8N=E/S__\>%-/K__P`````/K-`;"<B+
MC9#\___!ZALQT@&%8/;__Q&59/;__XN58/;__P^LV0*+A9#\___!ZP(QVXF5
M,/K__XN5E/S__P^DPAZ+E33Z___!X!X)P8N%./W__X'&UL%BR@.UZ/K__S'(
M,X6(^___`<:+A3#Z__\/K-`;P>H;B86@]/__B96D]/__BX4P^O__BY4T^O__
MB[V,^___QX44_/__``````^DP@7!X`6)A5CV__^+A:#T__\+A5CV__^)E5SV
M__^+E8S[__\!QHN%B/O__XFU$/S__XNUB/O__P^DPAZ+E5S___\/K/X"P>`>
M"<:+A5C____![P(Q_P76P6+*B850]O__@](`BX4X_?__`850]O__B?")E53V
M__^+E3S]__\1E53V__^)^C':,<@QVC.%,/K__P&%4/;__Q&55/;__XN%$/S_
M_XN5%/S__P^LT!O!ZAN)A9CT__^+A1#\__^)E9ST__^+E13\__\/I,(%P>`%
MB85(]O__BX68]/__"X5(]O__B95,]O__,=(!A5#V__\1E53V__^+E5#V__^+
MA3#Z___'A?3Z__\`````QX4\^O__`````(F5\/K__XN5-/K__P^LT`+!Z@*)
MA4#V__^+A3#Z__^)E43V__^+E33Z__\/I,(>B964]/__BY5`]O__P>`>B860
M]/__"<*+A43V__\+A93T__^)E3CV__^)E3CZ__^+E63___^)A3SV__^+A6#_
M__\%UL%BRHF%,/;__X/2``&-,/;__XF5-/;__Q&=-/;__S'2BX4X^O__,?HQ
MVHN-\/K__XN=]/K__\>%1/W__P`````Q\#.%$/S__P&%,/;__Q&5-/;__XN%
M\/K__P^DRP6+E?3Z___!X06+G13\__\/K-`;"<B+C1#\___!ZALQT@&%,/;_
M_Q&5-/;__XN5,/;__P^LV0*+A1#\___!ZP(QVXF50/W__XN5%/S__P^DPAZ+
ME6S____!X!X)P8N%:/___P76P6+*B84H]O__BX4X^O__@](``;4H]O__B94L
M]O__$;TL]O__,=(QVC'(,=HSA?#Z__\!A2CV__\1E2SV__^+M4#]__^+E43]
M__^+A4#]__^+O43]___'A9S\__\`````#ZS0&P^D]P6+O?3Z___!Y@4)\(NU
M\/K__\'J&S'2`84H]O__$94L]O__BY4H]O__#ZS^`HN%\/K__\'O`C'_B968
M_/__BY7T^O__#Z3"'HN5=/___\'@'@G&BX5P____!=;!8LJ)A2#V__^#T@"+
MA3CZ__\!A2#V__^)\(F5)/;__XN5//K__Q&5)/;__XGZ,=HQR#':,X5`_?__
M`84@]O__$94D]O__BY6<_/__BX68_/__QX64^___``````^LT!O!ZAN)A8CT
M__^+A9C\__^)E8ST__^+E9S\__\/I,(%P>`%B848]O__BX6(]/__"X48]O__
MB94<]O__,=(!A2#V__\1E23V__^+E2#V__^+A4#]__^)E9#[__^+E43]__\/
MK-`"P>H"B840]O__BX5`_?__B944]O__BY5$_?__#Z3"'HF5A/3__XN5$/;_
M_\'@'HF%@/3__PG"BX44]O__"X6$]/__B94(]O__B95(_?__B84,]O__QX5,
M_?__`````(N%>/___XN5?/___\>%1/K__P`````%UL%BRHF%`/;__XN%2/W_
M_X/2``&-`/;__XN-D/O__XF5!/;__Q&=!/;__S'2,?HQ\#':BYV4^___,X68
M_/__`84`]O__$94$]O__BX60^___#Z3+!8N5E/O__\'A!8N=G/S__P^LT!L)
MR(N-F/S__\'J&S'2`84`]O__$94$]O__BY4`]O__#ZS9`HN%F/S__\'K`C';
MB95`^O__BY6<_/__#Z3"'HM5A,'@'@G!BT6`!=;!8LJ)A?CU__^+A4C]__^#
MT@`!M?CU__^+M4#Z__^)E?SU__\1O?SU__\QTC':,<B+O43Z__\SA9#[__\Q
MV@&%^/7__Q&5_/7__XN%0/K__P^D]P6+E43Z___!Y@6+O93[___'A1S\__\`
M````#ZS0&PGPB[60^___P>H;,=(!A?CU__\1E?SU__^+E?CU__\/K/X"BX60
M^___P>\",?^)E1C\__^+E93[__\/I,(>BU6,P>`>"<:+18@%UL%BRH/2`(F%
M\/7__XN%2/W__XF5]/7__XN53/W__P&%\/7__XGP$97T]?__B?HQVC'(,=HS
MA4#Z__\!A?#U__\1E?3U__^+A1C\__^+E1S\___'A?SZ__\`````#ZS0&\'J
M&XF%>/3__XN%&/S__XF5?/3__XN5'/S__P^DP@7!X`6)A>CU__^+A7CT__\+
MA>CU__^)E>SU__\QT@&%\/7__Q&5]/7__XN5\/7__XN%0/K__XF5^/K__XN5
M1/K__P^LT`+!Z@*)A>#U__^+A4#Z__^)E>3U__^+E43Z__\/I,(>P>`>B85P
M]/__B95T]/__BY7@]?__QX5,^O__``````G"BX7D]?__"X5T]/__B95(^O__
MB978]?__BU64B87<]?__BT60!=;!8LJ)A=#U__^+A4CZ__^#T@`!C=#U__^+
MC?CZ__^)E=3U__\1G=3U__\QTC'Z,?`QVHN=_/K__S.%&/S__P&%T/7__Q&5
MU/7__XN%^/K__P^DRP6+E?SZ___!X04/K-`;"<C!ZALQT@&%T/7__Q&5U/7_
M_XN5T/7__XF54/W__XN='/S__XN%&/S__XN-&/S__XN5'/S__\>%5/W__P``
M``#'A:3\__\`````#ZS9`@^DPAZ+59S!X!X)P8M%F,'K`C';!=;!8LJ)A<CU
M__^+A4CZ__^#T@`!M<CU__^+M5#]__^)E<SU__\1O<SU__\QTC':,<B+O53]
M__\SA?CZ__\QV@&%R/7__Q&5S/7__XN%4/W__P^D]P6+E53]___!Y@6+O?SZ
M__\/K-`;"?"+M?CZ___!ZALQT@&%R/7__Q&5S/7__XN5R/7__P^L_@*+A?CZ
M___![P(Q_XF5H/S__XN5_/K__P^DPAZ+5:3!X!X)QHM%H`76P6+*B87`]?__
M@](`BX5(^O__`87`]?__B?")E<3U__^+E4SZ__\1E<3U__^)^C':,<@QVC.%
M4/W__P&%P/7__Q&5Q/7__XN%H/S__XN5I/S__\>%G/O__P`````/K-`;P>H;
MB85H]/__BX6@_/__B95L]/__BY6D_/__#Z3"!<'@!8F%N/7__XN%:/3__PN%
MN/7__XF5O/7__S'2`87`]?__$97$]?__BY7`]?__BX50_?__B968^___BY54
M_?__#ZS0`L'J`HF%L/7__XN%4/W__XF5M/7__XN55/W__\>%7/W__P`````/
MI,(>B95D]/__BY6P]?__P>`>B85@]/__"<*+A;3U__\+A63T__^)E5C]__^)
ME:CU__^+5:R)A:SU__^+1:@%UL%BRHF%H/7__XN%6/W__X/2``&-H/7__XN-
MF/O__XF5I/7__Q&=I/7__S'2,?HQ\#':BYV<^___,X6@_/__`86@]?__$96D
M]?__BX68^___#Z3+!8N5G/O__\'A!0^LT!L)R,'J&S'2`86@]?__$96D]?__
MBY6@]?__BYVD_/__BX6@_/__BXV@_/__B950^O__BY6D_/__QX54^O__````
M``^LV0(/I,(>BU6TP>`>"<&+1;#!ZP(QVP76P6+*B868]?__BX58_?__@](`
M`;68]?__B[50^O__B96<]?__$;V<]?__,=(QVC'(B[U4^O__,X68^___,=H!
MA9CU__\1E9SU__^+A5#Z__\/I/<%BY54^O__P>8%#ZS0&PGPP>H;,=(!A9CU
M__\1E9SU__^+E9CU__^)E2#\__^+O9S[__^+A9C[__^+M9C[__^+E9S[___'
MA23\__\`````#ZS^`@^DPAZ+5;S!X!X)QHM%N,'O`C'_!=;!8LJ)A9#U__^#
MT@"+A5C]__\!A9#U__^)\(F5E/7__XN57/W__Q&5E/7__XGZ,=HQR#':,X50
M^O__`860]?__$964]?__BX4@_/__BY4D_/__#ZS0&\'J&XF%6/3__XN%(/S_
M_XF57/3__XN5)/S__P^DP@7!X`6)A8CU__^+A5CT__\+A8CU__^)E8SU__\Q
MT@&%D/7__Q&5E/7__XN5D/7__XN%4/K__\>%!/O__P````#'A5SZ__\`````
MB94`^___BY54^O__#ZS0`L'J`HF%@/7__XN%4/K__XF5A/7__XN55/K__P^D
MPAZ)E53T__^+E8#U___!X!Z)A5#T__\)PHN%A/7__PN%5/3__XF56/K__XF5
M>/7__XM5Q(F%?/7__XM%P`76P6+*B85P]?__BX58^O__@](``8UP]?__B95T
M]?__$9UT]?__,=(Q^C'P,=HSA2#\__\!A7#U__\1E73U__^+E03[__^+C0#[
M__^+A0#[__^+G03[___'A63]__\`````#ZS0&P^DRP6+G23\___!X04)R(N-
M(/S__\'J&S'2`85P]?__$95T]?__BY5P]?__#ZS9`HN%(/S__\'K`C';B95@
M_?__BY4D_/__#Z3"'HM5S,'@'@G!BT7(!=;!8LJ)A6CU__^+A5CZ__^#T@`!
MM6CU__^+M6#]__^)E6SU__\1O6SU__\QTC':,<B+O63]__\SA0#[__\QV@&%
M:/7__Q&5;/7__XN%8/W__P^D]P6+E63]___!Y@4/K-`;"?#!ZALQT@&%:/7_
M_Q&5;/7__XN5:/7__XN]!/O__XN%`/O__XNU`/O__XF5J/S__XN5!/O__\>%
MK/S__P`````/K/X"#Z3"'HM5U,'@'@G&BT70P>\",?\%UL%BRHF%8/7__X/2
M`(N%6/K__P&%8/7__XGPB95D]?__BY5<^O__$95D]?__B?HQVC'(,=HSA6#]
M__\!A6#U__\1E63U__^+A:C\__^+E:S\__\/K-`;P>H;B85(]/__BX6H_/__
MB95,]/__BY6L_/__#Z3"!<'@!8F%6/7__XN%2/3__PN%6/7__XF57/7__S'2
M`85@]?__$95D]?__BY5@]?__BX5@_?__QX6D^___`````,>%;/W__P````")
ME:#[__^+E63]__\/K-`"P>H"B850]?__BX5@_?__B954]?__BY5D_?__#Z3"
M'HF51/3__XN54/7__\'@'HF%0/3__PG"BX54]?__"X5$]/__B95(]?__B95H
M_?__BU7<B85,]?__BT78!=;!8LJ)A4#U__^#T@`!C4#U__^)E43U__\1G43U
M__\QTHN%:/W__S'Z,=J+C:#[__^+G:3[___'A63Z__\`````B[UD^O__,?`S
MA:C\__\!A4#U__\1E43U__^+A:#[__\/I,L%BY6D^___P>$%QX6T_/__````
M``^LT!L)R,'J&S'2`85`]?__$95$]?__BY5`]?__BX6H_/__B95@^O__BY6L
M_/__#ZS0`L'J`HF%./7__XN%J/S__XF5//7__XN5K/S__XN-./7__P^DPAZ+
ME63Z___!X!X)P8F-L/S__XM-X(N%L/S__X'!UL%BR@'QB[5@^O__,X5H_?__
M,X6@^___`<&+A6#Z__\/I/<%P>8%#ZS0&PGPP>H;`<&)C2C\__^+G:3[__^+
MA:#[__^+C:#[__^+E:3[__^+=>C'A2S\__\`````#ZS9`@^DPAZ+E2S\___!
MX!X)P8N%L/S__\'K`H'&UL%BR@.U:/W__S'(,X5@^O__`<:+A2C\__\/K-`;
MP>H;B84X]/__BX4H_/__B94\]/__BY4L_/__#Z3"!<'@!8F%,/7__XN%./3_
M_PN%,/7__XF5-/7__P'&B?"+M93Y__\#A2#U___'1@0`````B0:+O2C\__\!
M?@C'1@P`````BY5D^O__B[5@^O__BX5@^O__B[UD^O__#ZS0`@^D]Q[!YAX)
M\(NUE/G__\'J`@%&$`%.&,=&%`````#'1AP`````B[VP_/__`7X@QT8D````
M`('$O`L``%M>7UW#C70F`(V\)P````!5B>6#["B%P(E]_(G'B5WTB77XB57H
M=0\QP(M=](MU^(M]_(GL7<.AT&8%"(7`B47L=.4/M@>$P'5$QT7P`````(M5
M[(L:A=MTSHG6C70F`(M%\(E\)`2)'"2)1"0(Z.FP__^%P'4+BU7PC003@#@]
M="F+7@2#Q@2%VW74ZYH\/8GZ=+:#P@$/M@*$P'4'*?J)5?#KK#P]=>OK\RMU
M[(/``8M5Z,'^`HDRZ6S___^)]E6)Y593B<.-=?2#[!")\HG8Z#K___^%P'0O
MC;8`````BT7TC12%``````,5T&8%"(/"!(L"A<")0OQU](GRB=CH"____X7`
M==>#Q!!;7EW#58GE@^P8C57\Z/+^___)PU6)Y8/L"(,]#&`%"/]T!Z$,8`4(
MR<.X>/\$".C0____A<!T!P^V`(3`=14QP*,,8`4(H0Q@!0C)PXVT)@`````\
M,`^5P`^VP.OCC;8`````58GE@^P(QP0D_____^@ZL/__QT0D!`````#'!"20
MXP0(Z&:R___)PY"-M"8`````58GE4X/L%*%08@4(#[858&(%"(M`!(A0&*%0
M8@4(BU`$H7QB!0@/MT`09B7_`6:)0AJA4&(%"(M8!,=$)`0`````QP0D%P$%
M".@.L/__B4,<H5!B!0B+4`2AA&(%"(E"(*%08@4(,=*+2`2A2&(%"(7`=`.+
M4&R)422A4&(%"(M`!,=`*`````"A4&(%"(M`!,=`+`````"A4&(%"(M0!*&`
M8@4(B4(P@\046UW#B?95B>575E.#['R%P(E%C'0%@#@`=0N#Q'Q;7E]=PXUV
M`(D$).@4L/__A<")19!TYI"+19")!"3H0;'__X7`#X2I````C5@(OX/_!`C\
MN0(```")WO.F=-F_@O\$"+D#````B=[SIG3)BT6,B00DZ(JQ__^)'"2)QNB`
ML?__C40&`HD$).C$L/__B5PD#(G&BT6,QT0D!(7_!`B)-"2)1"0(Z(>Q__^-
M192)1"0$B30DZ'BO__^#P`%T$`^W19PE`/```#T`0```=$&)-"3H&Z___XDT
M).BSL/__BT60B00DZ)BP__^%P`^%5____XM%D(D$).@5L?__BT6,B00DZ&JO
M__^#Q'Q;7E]=PXGPZ._^___KOHVV`````(V\)P````!5B>53B<.#['2-19R)
M1"0$B1PDZ,2M__^%P'47#[=%I"4`\```/0!```!T%#T`H```=`V#Q'0QP%M=
MPY"-="8`B1PDQT0D!`(```#HK*[__X7`#Y3`@\1T6P^VP%W#B?95B>575HG6
M4X/L+(E%W#'`@#H]#Y3``<:)-"3H7+#__XU5\(E%X(M%W.@2_/__A<")PW0J
MB00DZ$"P__\Y1>`/AY\````/M@:#Q@&(`X/#`83`=?&#Q"PQP%M>7UW#H=!F
M!0@QV[H(````BPB%R701@\,!BSR8A?]U]HT4G0@```"+#:!B!0B%R0^%#0$`
M`,<%H&(%"`$```")%"3H*Z___X7`B478#X01`0``H=!F!0B-/)T`````B7PD
M"(E$)`2+1=B)!"3HP:[__XM5V(D5T&8%"*'09@4(QT0'!`````")7?"+5=P/
MM@*$P`^$HP```#P]#X2;````C;8`````@\(!#[8"A,!U>XG0*T7<BTW@BUWP
MC40(`L'C`HD$)`,=T&8%".BBKO__A<")`P^$B0```(M5\*'09@4(BPR0BU7<
M#[8"A,"(`70=/#UT&8G0ZPB#P`&`^CUT#0^V4`&#P0&$TH@1=>O&`3V)RHUV
M``^V!H/&`8A"`8/"`83`=?#IS_[__SP]#X5S____C78`Z77___\QP.ES____
MB50D!(D$).ADK/__A<"CT&8%"'0,C3R=`````.D7____@\0LN/____];7E]=
MPXVV`````%6)Y5>_E?\$"%93@^Q,@#V5_P0(`,=%W)7_!`C'1>"+_P0(QT7D
MF/\$",=%Z([_!`C'1>R3_P0(QT7P%P$%"`^$Q````(U=W.L?C;8`````BU4(
MB?CHUOW__XM[!(/#!(`_``^$H````(GXZ`#[__^%P(G&=-J`.`!TU8M%"(DT
M)(E$)`3HPJS__X7`=<R+50B)%"3H$Z[__XE%T*&$`04(B00DZ`.N__^+5=")
M-"2-1`(!B47,Z/&M__\#1<R)!"3H-JW__XM5"(ET)!#'1"0$O``%"(E4)`B)
M1<BAA`$%"(E$)`R+1<B)!"3H[*W__XM5R(GXZ#;]__^+>P2#PP2`/P`/A6#_
M__^#Q$Q;7E]=P^L-D)"0D)"0D)"0D)"0D%6)Y5=6@^PPH2AB!0B)1?0QP*%<
M`04(B472H6`!!0B)1=:A9`$%"(E%VJ%H`04(B47>H6P!!0B)1>*A<`$%"(E%
MYJ%T`04(B47JH7@!!0B)1>X/MP5\`04(9HE%\KBE_P0(Z)GY__^XKO\$".B/
M^?__N+;_!`CHA?G__[B__P0(Z'OY__^XQO\$".AQ^?__N-;_!`CH9_G__[CB
M_P0(Z%WY__^X>/\$".A3^?__N.O_!`CH2?G__[CU_P0(Z#_Y__^X__\$".@U
M^?__N`P`!0CH*_G__[@5``4(Z"'Y__^X(``%".AG^?__A<!T#(G"N.O_!`CH
M%_S__[@Q``4(Z$WY__^%P'0,B<*X0P`%".C]^___N$X`!0CH,_G__X7`="^)
MPKCB_P0(Z./[__^Z>@`%"+C&_P0(Z-3[__^+1?0S!2AB!0AU1H/$,%Y?7<.)
M]KA>``4(Z/;X__^%P'0.B<*X>/\$".BF^___Z\'\C77COV\`!0BY"@```/.F
M=:^-5>VX>/\$".B%^___ZZ#HNJO__XVT)@````"-O"<`````58GE@^P(Z(&K
M__^)!"3HR:K__S'2A<!T`HL0R8G0PY!5B>6#[!B)7?2+70B)=?B)??R%VW0)
M#[8[B?B$P'48QT4(@_\$"(M=](MU^(M]_(GL7>FUJ/__B1PDZ(VK__\!V(U0
M_SG3<R:+#8`!!0@/MD#_#[8QB?$XR'0,ZS:-=@`/M@HXP75L@^H!.=-R\CG:
M=3"+%8`!!0B)^#H"=*&+#8`!!0B)30CKG8VT)@`````/M@*)\3C!=-6#Z@$Y
MTW+PZ\R#Z@$YTW,-BPV``04(#[8".@%T["G:,<F-0@(]``0``'83BUWTB<B+
M=?B+??R)[%W#B<CKO(U"`8E$)`B)7"0$QP0DP&(%".B^J/__N<!B!0CKSXUT
M)@"-O"<`````58GE@^P8B5WXBUT(B77\B1PDZ.G^__^)!"3H,:S__XG&Z'KW
M__^%P'0)A=MT!8`[`'4-BUWXBW7\B>Q=PXUV`,=$)`1\``4(B30DZ!RI__\Y
MQG7?BW7\B=B+7?B)[%WI;/C__XVV`````(V_`````(U,)`2#Y/#_<?R-00A5
MB>57B<]64U&#[!B)1"0(C4$$B40D!(D,).@PJ/__@#U,8@4(``^$'@$``(`-
M36(%"`,QTHL/4HU!!5#?+"2#Q`C<!0@"!0C=!1`"!0C9R=KIW^">#X=(`0``
MC02-%````(D$).A%JO__H\QF!0B)P8M'!(L`QT$$@0`%",=!""`"!0C'00R$
M``4(B0''!<AF!0@$````BQ^#^P$/CMX```"+=P2-0?RZ`0```(E%[(UV`(L$
MEHE$D0R#P@$YTW_RBT7LQT28$`````#'1"00`````(E,)`R+!\=$)`20_@0(
M@\`#B40D"*'`9@4(B00DZ/FF__^%P(G#='"AP&8%"(D$).@FJ/__N-;_!`CH
M`/;__X7`=""AP&8%"(D$).B;J?__Z&:I__^#Q!B)V%E;7E]=C6'\PZ'$9@4(
MA<!T2XD$).@[_O__Z\WH8*C__X7`H\!F!0AT7XD$).A/IO__Q@4@8@4(`.G`
M_O__H<!F!0B)!"3H-J?__XG#Z7S___^-0?R)1>SI-O___[CB_P0(Z'[U__^%
MP*/$9@4(=:+I=/___\=$)`1H8@4(QP0D#@$%".AHI?__QP0D`0```.B\I___
M58GE5U93@>R<!```BWT(H2AB!0B)1?`QP+CB_P0(BUT,Z"KU__^+-8`!!0B)
M/"2)="0$B86`^___Z.ZF__^%P'0HB?JX__\$".C"]___BU7P,Q4H8@4(B?@/
MA7@!``"!Q)P$``!;7E]=PXD\).@:J/__BQ6$`04(B1PDB50D!(F%?/O__^@2
MIO__A<")PW2RBX5\^___@\`!B85X^___D(`[`'4%NX/_!`B+A8#[__^%P'0:
MBY6`^___B5PD!(D4).AVIO__A<`/A+$```")'"3HMJ?__XG!#[9$`_\Z!G45
MC10+#[9"_H/I`<9"_P"#Z@$Z!G3NBX5X^___`<@]_P,```^/.?___XV5\/O_
M_XD4)(E\)!")="0,B5PD",=$)`2\``4(Z)&G__^-A9#[__^)1"0$C87P^___
MB00DZ'FE__^%P'43#[>%F/O__R4`\```/0"```!T/HL5A`$%",<$)`````")
M5"0$Z"RE__^)PX7;#X4F____Z</^__^AA`$%",<$)`````")1"0$Z`BE__^)
MP^O:C97P^___QT0D!`$```")%"3H_J3__X7`=:B-E?#[__^X__\$".A.]O__
MC87P^___B00DZ-RC__^)Q^EW_O__Z'"F__^-="8`58GE5U93@>Q<@0``BT4(
MBQ4H8@4(B57L,=+'A11___^'``4(QX48?___CP`%"(F%R'[__[CB_P0(QX4<
M?___@_\$",>%('___Q<!!0C'A?Q^__]#``4(QX4`?___/``%",>%!'___YD`
M!0C'A0A___^*``4(QX4,?___H0`%",>%$'___Q<!!0C'A21___^E``4(QX4H
M?___J@`%",>%+'___Q<!!0CHQ/+__X7`B<-T"8`X``^%\P(``)"-="8`Z/OY
M__^[`0```(VU)'___X7`B<</A+0"```/M@>$P'0NB?D/OM"%TG@7.Q548@4(
M?0^A7&(%"/=$D#0`!0``=0/&`5\/MD$!@\$!A,!UU+L!````QX7,?O__````
M`.L-BX7,?O__@\,!A<!U0(N$G?A^__^`.``/A(D"``#H+O+__X7`B<9TV.B#
M]/__A<"0=,Z)-"2#PP'H;Z+__XF%S'[__XN%S'[__X7`=,"+C<Q^__^)#"3H
M,:7__XD\)(G#Z">E__^-G`,$!```B1PDZ&BD__^)'"2)A=!^___H6J3__XE\
M)!2+/8`!!0C'1"00?``%",=$)`2Z``4(B7PD#(F%Q'[__XN%S'[__XN5Q'[_
M_XE$)`B)%"3H_J3__XN-Q'[__\=$)`3M`0``B0PDZ/BC__^XCO\$".AR\?__
MA<`/A)L!``")!"3HOJ'__XN]R'[__XE$)`2+!XD$).C^^___A<")PP^$=0$`
M`(D<).AXI/__@_@#B86X?O__#X_)`0``Z#CQ__^%P'4>QT0D!`````")'"3H
M4*/__X7`B874?O__#X4V`@``NGH`!0BX>/\$".BW\___,=OH#*3__XL-@`$%
M"(N]Q'[__\=$)!07`04(QT0D!.$`!0B)3"0,B7PD"(E$)!"+A=!^__^)!"3H
M)J3__^M,Z&^B__^#.!%U7>C%H___BQ6``04(@\,!BXW$?O__B[W0?O__QT0D
M&!<!!0B)7"04B50D#(E$)!")3"0(QT0D!.\`!0B)/"3HV*/__XN%T'[__\=$
M)`3M`0``B00DZ-*B__^#P`%TF8N5Q'[__XD4).@/H___BY70?O__N.+_!`CH
M\_+__XN-T'[__XD,).BU]/__BWWL,STH8@4(BX70?O__#X6B!P``@<1<@0``
M6UY?7<.0C70F`.C[[___A<!T"HD$).A+H/__B<>#PP&%_P^%3/W__XM$GOR`
M.`!UV;^S``4(Z6[]__^+A<A^__^+&.E^_O__B00DZ$KT__^)'"3H#J#__XF%
MT'[__^N%O@$```#K%(UV`(N%S'[__X/&`87`#X6,_?__BYRU$'___X`[``^$
M?/W__XG8Z-CQ__^%P'34B1PDZ,B?__^)A<Q^___KQ(UT`_RX!0```/R_PP`%
M"(G!\Z8/A1[^__^#O;A^__\$=!F+O;A^__^+%8`!!0@/MD0?^SH"#X7\_?__
MBXW(?O__BTD$A<F)C;Q^__\/A.7]__^)#"3H1J+__X/X`P^&U/W__XN]O'[_
M_[D%````_(UT!_RXR``%"(G'\Z8/A;7]__^+G;Q^___IJOW__XVT)@````#'
M1"0,`@```,=$)`3N____QT0D"/____^)!"3H?*#__XN5U'[__XV%,'___\=$
M)`@&````B40D!(D4).CLH?__@+TP?___`'4-@+TQ?___0P^$5P4``(N5U'[_
M_\=$)`P`````QT0D!`````#'1"0(`````(D4).@@H/__QX4P____`2-%9\>%
M-/___P````#'A3C___^)J\WOQX4\____`````,>%0/____[<NIC'A43___\`
M````QX5(____=E0R$,>%3/___P````#'A5#____PX=+#QX54____`````,>%
M6/___P````#'A5S___\`````QX5@____`````,>%9/___P````#'1:@`````
MD(N5U'[__XV%,'___\=$)`@`@```B40D!(D4).C\H/__A<")A>Q^__\/CJL!
M``"+A5C___^+E5S___^)A=A^__^+A>Q^__^)E=Q^__^)PHG!P?H?B=,/I,(#
MP>`#`X78?O__,?\YO=Q^__^)QG(8=P@YA=A^__]V#H.%8/___P&#E63___\`
MBT6H#ZS9'<'K'0&-8/___Q&=9/___X7`B;58____C;4P?___B;U<____C;UH
M____#X2+````Z;<```"+!HF%:/___XM&!(F%;/___XM&"(F%</___XM&#(F%
M=/___XM&$(F%>/___XM&%(F%?/___XM&&(E%@(M&'(E%A(M&((E%B(M&)(E%
MC(M&*(E%D(M&+(E%E(M&,(E%F(M&-(E%G(M&.(E%H(M&/(/&0(.M['[__T")
M1:2-A3#____H>:'__X.]['[__S\/CVW___^+C>Q^__^)/"2)="0$B4PD".@"
MG___B[WL?O__B7VHZ8C^__^+G>Q^__^Z0````"G".=-^`HG3C;UH____C00'
MC94P?___B5PD"(E4)`2)!"3HPI[__XG8`T6H@_A`B46H#X5%_O__C;4P?___
MC84P____`=XIG>Q^___H[*#__^EN____BXW4?O__B0PDZ.6=__^+E5S___^+
MA5C___^+G6#___^+M63___^)E>1^__^)A>!^__\/K-`#B<&#X3_!Z@.-40&#
M^CC&A"EH____@`^.2P(``+A`````*="-E"EI____B10DC;UH____B40D",=$
M)`0`````Z/F<__^-A3#____H8J#__[D.````,<#\\ZN)\HG8#ZS0&(A%H,'J
M&(G8B?(/K-`0B$6AP>H0B=B)\@^LT`B(1:+!Z@B+A>!^__^+E>1^__^-=:^(
M7:.-?=@/K-`8B$6DP>H8BX7@?O__BY7D?O__#ZS0$(A%I<'J$(N%X'[__XN5
MY'[__P^LT`C!Z@@/MI7@?O__B$6FC84P____B%6GZ,Z?__^+C3#___^+G33_
M__^)R(G:#ZS0&(A%V,'J&(G(B=H/K-`0B$79P>H0B<B)VHN=//___XA-VXN-
M./___P^LT`B(1=K!Z@B)VHG(#ZS0&(A%W,'J&(G(B=H/K-`0B$7=P>H0B<B)
MVHN=1/___XA-WXN-0/___P^LT`B(1=[!Z@B)VHG(#ZS0&(A%X,'J&(G(B=H/
MK-`0B$7AP>H0B<B)VHN=3/___XA-XXN-2/___P^LT`B(1>+!Z@B)VHG(#ZS0
M&(A%Y,'J&(G(B=H/K-`0B$7EP>H0B<B)VHN=5/___XA-YXN-4/___P^LT`B(
M1>;!Z@B)VHG(#ZS0&(A%Z,'J&(G(B=H/K-`0B$7IP>H0B<B)VC';#ZS0"(A%
MZL'J"(A-ZP^V!#N#PP&)-"2#Q@+'1"0$W``%"(E$)`CH_9S__X/[%'7=BSV`
M`04(C4VOBX7$?O__BY70?O__QD77`,=$)!07`04(B4PD$(E\)`R)1"0(QT0D
M!,T`!0B)%"3HNYS__^GY^/__N#@````IT(V4*6G___^)1"0(QT0D!`````")
M%"3HM)K__^G+_?__@+TR?___00^%G/K__X"],W___T,/A8_Z__^`O31___](
M#X6"^O__@+TU?___10^%=?K__XN-U'[__XV],'___\=$)`P"````QT0D!,;_
M___'1"0(_____XD,).B/FO__BX74?O__B7PD!,=$)`@I````B00DZ`6<__^+
M#8`!!0B)?"00BX70?O__B[W$?O__QT0D%!<!!0B)3"0,QT0D!,T`!0B)?"0(
MB00DZ-^;___I'?C__^AEF___B?:-O"<`````58GE@>PX"```H2AB!0B)1?`Q
MP(E=](V=[_O__XEU^(E]_.A5F___QT0D#``!!0C'1"0$!0$%"(D<)(E$)`CH
MB9O__X7`>1PQVXM5\#,5*&(%"(G8=52+7?2+=?B+??R)[%W#C;WN]___QT0D
M"``$``")?"0$B1PDZ&^;__^%P(G&>,2-0`&)!"3H7IK__X7`=+6)PXET)`B)
M?"0$B00DZ&B:___&!#,`ZY_HK9K__Y!5B>5=Z4?___^-M"8`````5;C&_P0(
MB>575E.#[!S&!5AB!0@!Z(;G__^%P'0)@#@Q#X2Y`0``Z"3M___'1"0("P``
M`,=$)`0!````QP0D$0$%".BTF?__A<`/A(X```"+0`PQ]H,]R&8%"`&+>!A^
M;+L!````ZRF+4`RAS&8%"(L$F(E4)`2)!"3H#9G__X7`=4J#Q@&#PP$Y'<AF
M!0A^/,=$)`@`````B70D!(D\).@GFO__A<!T)(L`]D`)!'6WQT0D"`(```#'
M1"0$`````(D$).CSEO__B<+KGHL5R&8%"(U"_SGP#X3<````QT0D"`4```#'
M1"0$`0```,<$)!8!!0CH`IG__X7`B<-T),=$)`08`04(BT`,BP")!"3HAY?_
M_XM##(L`]D`*0`^%T0```,=$)`@%````QT0D!`$```#'!"0>``4(Z+R8__^%
MP(G&=".X__\$".A0YO__A<`/A*T```")1"0$BT8,BP")!"3H,Y?__[CB_P0(
MQ@588@4(`,<%)&(%"`````#H'.;__X7`H\1F!0@/A,\```#'1"0$[0$``(D$
M).A[F/__A<!T#8/X$70(@_C_C78`=7Z#Q!Q;7E]=PX/J`0^.&____[L!````
MB3PD@\,!Z#F6__\Y'<AF!0A_[>G^_O__@'@!``^$0O[__XVV`````.DR_O__
MB00DZ!^6__^-=@#I'____^CF_?__A<")PXGV=$*)1"0$BT8,BP")!"3H>9;_
M_XD<).A!F/__Z3G___^)1"0,H<1F!0B)1"0(H<QF!0B+`,<$)+@!!0B)1"0$
MZ%B5__^AS&8%"(L`Z?C^__^AS&8%"(D$).C#\?__BQW,9@4(H\1F!0B+1@R+
M`/9`"01T/HM`#(E<)`2)!"3H.I7__XG#BT8,BP#V0`D$=#R+0`R)1"0(H<QF
M!0B)7"0,BP#'!"2(`04(B40D!.CKE/__QT0D"`(```#'1"0$`````(D$).CC
ME/__ZZO'1"0(`@```,=$)`0`````B00DZ,F4___KK8UT)@"-O"<`````58GE
M@^P8QT0D"!T!!0C'1"0$_)0$",<$)"<!!0CHBI7__\G#C;8`````C;\`````
M58GE@^P8Z,7____'1"00`````,=$)`P7`04(QT0D"!<!!0C'1"0$8/L$",<$
M)$,!!0CHQ93__\G#D)"0D)"0D%6)Y5.#[`2A#&$%"(/X_W02,=O_T(N#"&$%
M"(/K!(/X_W7P@\0$6UW#D)"0@^P,Z%R8__^#Q`S#````````````````````
M````````````)$9R965"4T0Z('-R8R]L:6(O8W-U+VDS.#8M96QF+V-R=&DN
M4RQV(#$N-RXR,BXQ+C(N,2`R,#`Y+S$P+S(U(#`Q.C$P.C(Y(&ME;G-M:71H
M($5X<"`D`%!!4E]#3$5!3@`N+@`E<R\E<P!,24)0051(`$193$1?3$E"4D%2
M65]0051(`%!%4DPU3$E"`%!%4DQ,24(`4$523#5/4%0`4$523$E/`%!!4E])
M3DE424%,25I%1`!005)?4U!!5TY%1`!005)?5$5-4`!005)?1$5"54<`4$%2
M7T-!0TA%`%!!4E]04D]'3D%-10!005)?05)'0P!005)?05)'5E\P`%!!4E]'
M3$]"04Q?1$5"54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?
M1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`<&%R
M+0`M90`M+0!#.EQ414U0`"]V87(O=&UP+P!414U01$E2`%1-4`!54T52`%53
M15).04U%`%-94U1%30`E<R5S)7,E<P!P87)L`"YP87(`)7,E<V-A8VAE+25S
M)7,`)3`R>``E<R5S=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`9FEL90`O
M<')O8R\E:2\E<P!!4D=6`!@`<&5R;`!P97)L>'-I+F,`1'EN84QO861E<CHZ
M8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`#H```!?7T5.
M5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(`````"7``4(6`$%""5S.B!E
M>&5C=71I;VX@;V8@)7,@9F%I;&5D("T@86)O<G1I;F<@=VET:"`E:2X*`"5S
M.B!C<F5A=&EO;B!O9B!P<FEV871E('1E;7!O<F%R>2!S=6)D:7)E8W1O<GD@
M)7,@9F%I;&5D("T@86)O<G1I;F<@=VET:"`E:2X*`````````````````(#_
M___/07!A<BYP;```(R$O=7-R+V)I;B]P97)L"F5V86P@)V5X96,@+W5S<B]B
M:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PH@("`@:68@,#L@(R!N;W0@<G5N
M;FEN9R!U;F1E<B!S;VUE('-H96QL"@IP86-K86=E(%]?<&%R7W!L.PH*(R`M
M+2T@5&AI<R!S8W)I<'0@;75S="!N;W0@=7-E(&%N>2!M;V1U;&5S(&%T(&-O
M;7!I;&4@=&EM92`M+2T*(R!U<V4@<W1R:6-T.PH*(VQI;F4@,34X"@IM>2`H
M)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%
M3E9[4$%27T-,14%.?2D@>PH@("`@<F5Q=6ER92!&:6QE.CI496UP.PH@("`@
M<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*("`@(')E<75I<F4@1FEL93HZ4W!E
M8SL*("`@(&UY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D
M<&%R7W1E;7`I.PH@("`@;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A
M<E]T96UP(GTI.PH@("`@1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@
M+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["B`@("!R;61I
M<B`D<&%R7W1E;7`["B`@("`C($1O;B=T(')E;6]V92!T;W!D:7(@8F5C875S
M92!T:&ES(&-A=7-E<R!A(')A8V4@=VET:"!O=&AE<B!A<'!S"B`@("`C('1H
M870@87)E('1R>6EN9R!T;R!S=&%R="X*"B`@("!I9B`H+60@)'!A<E]T96UP
M("8F("1>3R!N92`G35-7:6XS,B<I('L*("`@("`@("`C(%-O;65T:&EN9R!W
M96YT('=R;VYG('5N;&EN:VEN9R!T:&4@=&5M<&]R87)Y(&1I<F5C=&]R>2X@
M(%1H:7,*("`@("`@("`C('1Y<&EC86QL>2!H87!P96YS(&]N('!L871F;W)M
M<R!T:&%T(&1I<V%L;&]W('5N;&EN:VEN9R!S:&%R960*("`@("`@("`C(&QI
M8G)A<FEE<R!A;F0@97AE8W5T86)L97,@=&AA="!A<F4@:6X@=7-E+B!5;FQI
M;FL@=VET:"!A(&)A8VMG<F]U;F0*("`@("`@("`C('-H96QL(&-O;6UA;F0@
M<V\@=&AE(&9I;&5S(&%R92!N;R!L;VYG97(@:6X@=7-E(&)Y('1H:7,@<')O
M8V5S<RX*("`@("`@("`C($1O;B=T(&1O(&%N>71H:6YG(&]N(%=I;F1O=W,@
M8F5C875S92!O=7(@<&%R96YT('!R;V-E<W,@=VEL;`H@("`@("`@(",@=&%K
M92!C87)E(&]F(&-L96%N:6YG('1H:6YG<R!U<"X*"B`@("`@("`@;7D@)'1M
M<"`](&YE=R!&:6QE.CI496UP*`H@("`@("`@("`@("!414U03$%412`]/B`G
M=&UP6%A86%@G+`H@("`@("`@("`@("!$25(@/3X@1FEL93HZ0F%S96YA;64Z
M.F1I<FYA;64H)'1O<&1I<BDL"B`@("`@("`@("`@(%-51D9)6"`]/B`G+F-M
M9"<L"B`@("`@("`@("`@(%5.3$E.2R`]/B`P+`H@("`@("`@("D["@H@("`@
M("`@('!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL
M="`Q,"!=.R!D;PH@("!R;2`M<F8@)R1P87)?=&5M<"<*("`@:68@6R!<(2`M
M9"`G)'!A<E]T96UP)R!=.R!T:&5N"B`@("`@("!B<F5A:PH@("!F:0H@("!S
M;&5E<"`Q"B`@('@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M
M/F9I;&5N86UE("X@(B<*(CL*("`@("`@("`@("`@8VAM;V0@,#<P,"PD=&UP
M+3YF:6QE;F%M93L*("`@("`@("!M>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@
M+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*("`@("`@("!C;&]S92`D=&UP.PH@
M("`@("`@('-Y<W1E;2@D8VUD*3L*("`@("`@("!O=71S*'%Q*%-P87=N960@
M8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0H@("`@
M("`@("`@("`@+B`D=&UP+3YF:6QE;F%M92D["B`@("!]"GT@?0H*0D5'24X@
M>PH@("`@26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E
M<FYA;',Z.E!!4CHZ0D]/5#L*"B`@("!E=F%L('L*"E]P87)?:6YI=%]E;G8H
M*3L*"FEF("AE>&ES=',@)$5.5GM005)?05)'5E\P?2!A;F0@)$5.5GM005)?
M05)'5E\P?2`I('L*("`@($!!4D=6(#T@;6%P("1%3E9[(E!!4E]!4D=67R1?
M(GTL("@Q("XN("1%3E9[4$%27T%21T-]("T@,2D["B`@("`D,"`]("1%3E9[
M4$%27T%21U9?,'T["GT*96QS92!["B`@("!F;W(@*&ME>7,@)45.5BD@>PH@
M("`@("`@(&1E;&5T92`D14Y6>R1??2!I9B`O7E!!4E]!4D=67R\["B`@("!]
M"GT*"FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["@HC(&9I>"`D<')O
M9VYA;64@:68@:6YV;VME9"!F<F]M(%!!5$@*;7D@)4-O;F9I9R`]("@*("`@
M('!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I
M+`H@("`@7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC
M>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*("`@(%]D96QI;2`@("`@(#T^("@D
M7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["@I?<V5T7W!R
M;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*"B,@36%G:6,@<W1R:6YG(&-H
M96-K:6YG(&%N9"!E>'1R86-T:6YG(&)U;F1L960@;6]D=6QE<R![>WL*;7D@
M*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*("`@(&QO8V%L("1324=[7U]7
M05).7U]](#T@<W5B('M].PH*("`@(",@0VAE8VL@9FEL92!T>7!E+"!G970@
M<W1A<G0@;V8@9&%T82!S96-T:6]N('M[>PH@("`@;W!E;B!?1D@L("<\)RP@
M)'!R;V=N86UE(&]R(&QA<W0["B`@("!B:6YM;V1E*%]&2"D["@H@("`@;7D@
M)&)U9CL*("`@('-E96L@7T9(+"`M."P@,CL*("`@(')E860@7T9(+"`D8G5F
M+"`X.PH@("`@;&%S="!U;FQE<W,@)&)U9B!E<2`B7&Y005(N<&U<;B(["@H@
M("`@<V5E:R!?1D@L("TQ,BP@,CL*("`@(')E860@7T9(+"`D8G5F+"`T.PH@
M("`@<V5E:R!?1D@L("TQ,B`M('5N<&%C:R@B3B(L("1B=68I+"`R.PH@("`@
M<F5A9"!?1D@L("1B=68L(#0["@H@("`@)&1A=&%?<&]S(#T@*'1E;&P@7T9(
M*2`M(#0["B`@("`C('U]?0H*("`@(",@17AT<F%C=&EN9R!E86-H(&9I;&4@
M:6YT;R!M96UO<GD@>WM["B`@("!M>2`E<F5Q=6ER95]L:7-T.PH@("`@=VAI
M;&4@*"1B=68@97$@(D9)3$4B*2!["B`@("`@("`@<F5A9"!?1D@L("1B=68L
M(#0["B`@("`@("`@<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I
M.PH*("`@("`@("!M>2`D9G5L;&YA;64@/2`D8G5F.PH@("`@("`@(&]U=',H
M<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*("`@("`@("!M
M>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@
M/R`D,2`Z('5N9&5F.PH@("`@("`@(&UY("@D8F%S96YA;64L("1E>'0I(#T@
M*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*"B`@("`@("`@<F5A
M9"!?1D@L("1B=68L(#0["B`@("`@("`@<F5A9"!?1D@L("1B=68L('5N<&%C
M:R@B3B(L("1B=68I.PH*("`@("`@("!I9B`H9&5F:6YE9"@D97AT*2!A;F0@
M)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*("`@("`@("`@("`@
M;7D@*"1O=70L("1F:6QE;F%M92D@/2!?=&5M<&9I;&4H)&5X="P@)&-R8RD[
M"B`@("`@("`@("`@(&EF("@D;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM
M;V1E*"1O=70I.PH@("`@("`@("`@("`@("`@<')I;G0@)&]U="`D8G5F.PH@
M("`@("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("`@("`@("`@(&-H
M;6]D(#`W-34L("1F:6QE;F%M93L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA
M;64["B`@("`@("`@("`@("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N
M86UE?2`]("1F=6QL;F%M93L*("`@("`@("!]"B`@("`@("`@96QS:68@*"`D
M9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%2
M7U1%35!]("D@>PH@("`@("`@("`@("`C('-H;W5L9"!B92!M;W9E9"!T;R!?
M=&5M<&9I;&4H*0H@("`@("`@("`@("!M>2`D9FEL96YA;64@/2`B)$5.5GM0
M05)?5$5-4'TO)&)A<V5N86UE)&5X="(["B`@("`@("`@("`@(&]U=',H(E-(
M3$E".B`D9FEL96YA;65<;B(I.PH@("`@("`@("`@("!O<&5N(&UY("1O=70L
M("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D
M92@D;W5T*3L*("`@("`@("`@("`@<')I;G0@)&]U="`D8G5F.PH@("`@("`@
M("`@("!C;&]S92`D;W5T.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@
M("`@("`@("`@)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*("`@("`@("`@
M("`@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["B`@
M("`@("`@("`@("`@("!B=68@/3X@)&)U9BP*("`@("`@("`@("`@("`@(&-R
M8R`]/B`D8W)C+`H@("`@("`@("`@("`@("`@;F%M92`]/B`D9G5L;&YA;64L
M"B`@("`@("`@("`@('T["B`@("`@("`@?0H@("`@("`@(')E860@7T9(+"`D
M8G5F+"`T.PH@("`@?0H@("`@(R!]?7T*"B`@("!L;V-A;"!`24Y#(#T@*'-U
M8B!["B`@("`@("`@;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PH*("`@("`@
M("!R971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["@H@("`@("`@
M(&UY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]
M('Q\(&1O('L*("`@("`@("`@("`@;7D@)&ME>3L*("`@("`@("`@("`@9F]R
M96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2!["B`@("`@("`@("`@("`@("!N
M97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*("`@("`@("`@("`@("`@("1K
M97D@/2`D7SL@;&%S=#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!D96QE
M=&4@)')E<75I<F5?;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PH@("`@
M("`@('T@;W(@<F5T=7)N.PH*("`@("`@("`D24Y#>R1M;V1U;&5](#T@(B]L
M;V%D97(O)&9I;&5N86UE+R1M;V1U;&4B.PH*("`@("`@("!I9B`H)$5.5GM0
M05)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PH@("`@
M("`@("`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE
M("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@('!R
M:6YT("1F:"`D9FEL96YA;64M/GMB=69].PH@("`@("`@("`@("!S965K*"1F
M:"P@,"P@,"D["B`@("`@("`@("`@(')E='5R;B`D9F@["B`@("`@("`@?0H@
M("`@("`@(&5L<V4@>PH@("`@("`@("`@("!M>2`H)&]U="P@)&YA;64I(#T@
M7W1E;7!F:6QE*"<N<&TG+"`D9FEL96YA;64M/GMC<F-]*3L*("`@("`@("`@
M("`@:68@*"1O=70I('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&]U="D[
M"B`@("`@("`@("`@("`@("!P<FEN="`D;W5T("1F:6QE;F%M92T^>V)U9GT[
M"B`@("`@("`@("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&]P96X@;7D@)&9H+"`G/"<L("1N86UE(&]R(&1I92`D(3L*
M("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("!R971U<FX@
M)&9H.PH@("`@("`@('T*"B`@("`@("`@9&EE(")";V]T<W1R87!P:6YG(&9A
M:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["B`@("!]+"!`24Y#*3L*
M"B`@("`C($YO=R!L;V%D(&%L;"!B=6YD;&5D(&9I;&5S('M[>PH*("`@(",@
M:6YI=&EA;&EZ92!S:&%R960@;V)J96-T('!R;V-E<W-I;F<*("`@(')E<75I
M<F4@6%-,;V%D97(["B`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("!R97%U
M:7)E($-A<G`Z.DAE879Y.PH@("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD[
M"B`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["@H@("`@(R!N
M;W<@;&5T)W,@=')Y(&=E='1I;F<@:&5L<&5R(&UO9'5L97,@9G)O;2!W:71H
M:6X*("`@(')E<75I<F4@24\Z.D9I;&4["@H@("`@(R!L;V%D(')E<W0@;V8@
M=&AE(&=R;W5P(&EN"B`@("!W:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@
M:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PH@("`@("`@("-L;V-A;"`D24Y#
M>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@
M("`@("`@=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^
M("]"4T1004XO*2!["B`@("`@("`@("`@(",@<F5Q=6ER92!M;V1U;&5S+"!D
M;R!O=&AE<B!E>&5C=71A8FQE(&9I;&5S"B`@("`@("`@("`@(&EF("@D9FEL
M96YA;64@/7X@+UPN<&UC/R0O:2D@>PH@("`@("`@("`@("`@("`@<F5Q=6ER
M92`D9FEL96YA;64["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92![
M"B`@("`@("`@("`@("`@("`C(%-K:7`@06-T:79E4W1A=&4G<R!S:71E8W5S
M=&]M:7IE+G!L(&9I;&4Z"B`@("`@("`@("`@("`@("!D;R`D9FEL96YA;64@
M=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!D96QE=&4@)')E<75I<F5?
M;&ES='LD9FEL96YA;65].PH@("`@?0H*("`@(",@?7U]"@H@("`@;&%S="!U
M;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B`@("`D<W1A<G1?<&]S(#T@
M*'1E;&P@7T9(*2`M(#0["GT*(R!]?7T*"B,@07)G=6UE;G0@<')O8V5S<VEN
M9R![>WL*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H
M+"`D8V%C:&5?;F%M92D["@ID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@
M(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*
M"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*(R!$;VXG="!S
M=V%L;&]W(&%R9W5M96YT<R!F;W(@8V]M<&EL960@97AE8W5T86)L97,@=VET
M:&]U="`M+7!A<BUO<'1I;VYS"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;
M,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PH@("`@;7D@)61I
M<W1?8VUD(#T@<7<H"B`@("`@("`@<"`@(&)L:6)?=&]?<&%R"B`@("`@("`@
M:2`@(&EN<W1A;&Q?<&%R"B`@("`@("`@=2`@('5N:6YS=&%L;%]P87(*("`@
M("`@("!S("`@<VEG;E]P87(*("`@("`@("!V("`@=F5R:69Y7W!A<@H@("`@
M*3L*"B`@("`C(&EF('1H92!A<'`@:7,@:6YV;VME9"!A<R`B87!P;F%M92`M
M+7!A<BUO<'1I;VYS("TM<F5U<V4@4%)/1U)!32!`4%)/1U]!4D=6(BP*("`@
M(",@=7-E('1H92!A<'`@=&\@<G5N('1H92!G:79E;B!P97)L(&-O9&4@:6YS
M=&5A9"!O9B!A;GET:&EN9R!F<F]M('1H90H@("`@(R!A<'`@:71S96QF("AB
M=70@<W1I;&P@<V5T('5P('1H92!N;W)M86P@87!P(&5N=FER;VYM96YT(&%N
M9"!`24Y#*0H@("`@:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S
M92<I('L*("`@("`@("!S:&EF="!`05)'5CL*("`@("`@("`D14Y6>U!!4E]!
M4%!?4D554T5](#T@<VAI9G0@0$%21U8["B`@("!]"B`@("!E;'-E('L@(R!N
M;W)M86P@<&%R;"!B96AA=FEO=7(*"B`@("`@("`@;7D@0&%D9%]T;U]I;F,[
M"B`@("`@("`@=VAI;&4@*$!!4D=6*2!["B`@("`@("`@("`@("1!4D=66S!=
M(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["@H@("`@
M("`@("`@("!I9B`H)#$@97$@)TDG*2!["B`@("`@("`@("`@("`@("!P=7-H
M($!A9&1?=&]?:6YC+"`D,CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E
M;'-I9B`H)#$@97$@)TTG*2!["B`@("`@("`@("`@("`@("!E=F%L(")U<V4@
M)#(B.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G
M02<I('L*("`@("`@("`@("`@("`@('5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)T\G*2![
M"B`@("`@("`@("`@("`@("`D;W5T(#T@)#(["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@96QS:68@*"0Q(&5Q("=B)RD@>PH@("`@("`@("`@("`@("`@
M)&)U;F1L92`]("=S:71E)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E
M;'-I9B`H)#$@97$@)T(G*2!["B`@("`@("`@("`@("`@("`D8G5N9&QE(#T@
M)V%L;"<["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q
M("=Q)RD@>PH@("`@("`@("`@("`@("`@)'%U:65T(#T@,3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)TPG*2!["B`@("`@("`@
M("`@("`@("!O<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A
M;FYO="!O<&5N(&QO9SH@)"$B.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&5L<VEF("@D,2!E<2`G5"<I('L*("`@("`@("`@("`@("`@("1C86-H95]N
M86UE(#T@)#(["B`@("`@("`@("`@('T*"B`@("`@("`@("`@('-H:69T*$!!
M4D=6*3L*"B`@("`@("`@("`@(&EF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q
M?2D@>PH@("`@("`@("`@("`@("`@9&5L971E("1%3E9[)U!!4E]414U0)WT[
M"B`@("`@("`@("`@("`@("!I;FET7VEN8R@I.PH@("`@("`@("`@("`@("`@
M<F5Q=6ER92!005(Z.D1I<W0["B`@("`@("`@("`@("`@("`F>R)005(Z.D1I
M<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*("`@("`@("`@("`@("`@("9[
M(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["B`@("`@("`@("`@
M("`@("!E>&ET.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!U
M;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PH@("`@?0I]"@HC(%A86"`M+2!A
M9&0@+2UP87(M9&5B=6<@<W5P<&]R="$*"B,@?7U]"@HC($]U='!U="!M;V1E
M("@M3RD@:&%N9&QI;F<@>WM["FEF("@D;W5T*2!["B`@("!["B`@("`@("`@
M(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-
M4U=I;C,R)SL*("`@("`@("!R97%U:7)E($E/.CI&:6QE.PH@("`@("`@(')E
M<75I<F4@07)C:&EV93HZ6FEP.PH@("`@?0H*("`@(&UY("1P87(@/2!S:&EF
M="A`05)'5BD["B`@("!M>2`D>FEP.PH*"B`@("!I9B`H9&5F:6YE9"`D<&%R
M*2!["B`@("`@("`@;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A
M;FYO="!F:6YD("<D<&%R)SH@)"$B.PH@("`@("`@(&)I;FUO9&4H)&9H*3L*
M("`@("`@("!B;&5S<R@D9F@L("=)3SHZ1FEL92<I.PH*("`@("`@("`D>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["B`@("`@("`@*"`D>FEP+3YR96%D1G)O
M;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+
M*"D@*0H@("`@("`@("`@("!O<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D
M(2(["B`@("!]"@H*("`@(&UY("5E;G8@/2!D;R!["B`@("`@("`@:68@*"1Z
M:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI
M('L*("`@("`@("`@("`@)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B`@("`@
M("`@("`@("1M971A(#U^(',O7EQ3+BHO+VUS.PH@("`@("`@("`@("`D;65T
M82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["B`@("`@("`@?0H@("`@?3L*
M"B`@("`C($]P96X@:6YP=70@86YD(&]U='!U="!F:6QE<R![>WL*("`@(&QO
M8V%L("0O(#T@7#0["@H@("`@:68@*&1E9FEN960@)'!A<BD@>PH@("`@("`@
M(&]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["B`@("`@
M("`@8FEN;6]D92A005(I.PH@("`@("`@(&1I92`B)'!A<B!I<R!N;W0@82!0
M05(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*("`@('T*
M"B`@("!#<F5A=&50871H*"1O=70I(#L*("`@(`H@("`@;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=R@*("`@("`@("`D;W5T+`H@("`@("`@($E/.CI&:6QE.CI/
M7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/
M7U1254Y#*"DL"B`@("`@("`@,#<W-RP*("`@("D@;W(@9&EE("0A.PH@("`@
M8FEN;6]D92@D9F@I.PH*("`@("0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_
M(%PD9&%T85]P;W,@.B!U;F1E9CL*("`@('-E96L@7T9(+"`P+"`P.PH@("`@
M;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*("`@(&EF("@A)$5.5GM005)?
M5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PH@
M("`@("`@(')E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@("`@
M(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@
M)#`I"B`@("!]"B`@("!F;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV
M*2!["B`@("`@("`@;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*("`@
M("`@("`D=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*("`@
M("`@("!M>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?
M7R(["B`@("`@("`@;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD
M=F%L(CL*("`@("`@("`D;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B`@("`@
M("`@("`@("1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L
M96YG=&@H)'-E="DI*0H@("`@("`@('UE9SL*("`@('T*("`@("1F:"T^<')I
M;G0H)&QO861E<BD["B`@("`D+R`]('5N9&5F.PH@("`@(R!]?7T*"B`@("`C
M(%=R:71E(&)U;F1L960@;6]D=6QE<R![>WL*("`@(&EF("@D8G5N9&QE*2![
M"B`@("`@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@("`@(%!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*("`@("`@("!I;FET7VEN8R@I.PH*
M("`@("`@("!R97%U:7)E7VUO9'5L97,H*3L*"B`@("`@("`@;7D@0&EN8R`]
M('-O<G0@>PH@("`@("`@("`@("!L96YG=&@H)&(I(#P]/B!L96YG=&@H)&$I
M"B`@("`@("`@?2!G<F5P('L*("`@("`@("`@("`@(2]"4T1004XO"B`@("`@
M("`@?2!G<F5P('L*("`@("`@("`@("`@*"1B=6YD;&4@;F4@)W-I=&4G*2!O
M<@H@("`@("`@("`@("`H)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E
M>'!](&%N9`H@("`@("`@("`@("`@)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R
M:79L:6)E>'!]*3L*("`@("`@("!]($!)3D,["@H@("`@("`@(",@1FEL92!E
M>&ES=',@=&5S="!A9&1E9"!T;R!F:7@@4E0@(S0Q-SDP.@H@("`@("`@(",@
M1G5N;GDL(&YO;BUE>&ES=&EN9R!E;G1R>2!I;B!?/"XN+BYA=71O+T-O;7!R
M97-S+U)A=R]:;&EB+V%U=&]S<&QI="YI>"X*("`@("`@("`C(%1H:7,@:7,@
M82!B86YD+6%I9"!F:7@@=VET:"!N;R!D965P97(@9W)A<W`@;V8@=&AE(&ES
M<W5E+@H@("`@("`@(",@4V]M96)O9'D@<&QE87-E(&=O('1H<F]U9V@@=&AE
M('!A:6X@;V8@=6YD97)S=&%N9&EN9R!W:&%T)W,@:&%P<&5N:6YG+`H@("`@
M("`@(",@22!F86EL960N("TM(%-T969F96X*("`@("`@("!M>2`E9FEL97,[
M"B`@("`@("`@+UY?/"@N*RDD+R!A;F0@+64@)#$@86YD("1F:6QE<WLD,7TK
M*R!F;W(@:V5Y<R`E.CH["B`@("`@("`@)&9I;&5S>R1??2LK(&9O<B!V86QU
M97,@)4E.0SL*"B`@("`@("`@;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF
M:6=[;&EB7V5X='T["B`@("`@("`@;7D@)7=R:71T96X["@H@("`@("`@(&9O
M<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*("`@("`@("`@("`@;7D@*"1N
M86UE+"`D9FEL92D["@H@("`@("`@("`@("!F;W)E86-H(&UY("1D:7(@*$!I
M;F,I('L*("`@("`@("`@("`@("`@(&EF("@D;F%M92`]("1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)%]]*2!["B`@("`@("`@("`@("`@("`@("`@)&9I;&4@
M/2`D7SL*("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;
M7D-C72DI7%HO:2D@>PH@("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA
M;64I(#T@*"0Q+"`D,BD["B`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5L<VEF("AM(5XO;&]A
M9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PH@("`@("`@("`@("`@("`@("`@
M(&EF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@D
M<F5F+"`D,2D["B`@("`@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&5L<VEF("@M
M9B`B)&1I<B\D,2(I('L*("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE
M+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["B`@("`@("`@("`@("`@("`@
M("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!N97AT('5N;&5S
M<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["B`@
M("`@("`@("`@(&YE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<
M+EQ1)&QI8E]E>'1<120O.PH@("`@("`@("`@("!O=71S*"!J;VEN("(B+`H@
M("`@("`@("`@("`@("`@<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I
M;&4M/GMN86UE?2`Z("1F:6QE+`H@("`@("`@("`@("`@("`@<7$H(BXN+BD*
M("`@("`@("`@("`@*3L*"B`@("`@("`@("`@(&UY("1C;VYT96YT.PH@("`@
M("`@("`@("!I9B`H<F5F*"1F:6QE*2D@>PH@("`@("`@("`@("`@("`@)&-O
M;G1E;G0@/2`D9FEL92T^>V)U9GT["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@96QS92!["B`@("`@("`@("`@("`@("!O<&5N($9)3$4L("<\)RP@)&9I
M;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["B`@("`@("`@("`@
M("`@("!B:6YM;V1E*$9)3$4I.PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@
M/2`\1DE,13X["B`@("`@("`@("`@("`@("!C;&]S92!&24Q%.PH*("`@("`@
M("`@("`@("`@(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<
M)&-O;G1E;G0L("1F:6QE*0H@("`@("`@("`@("`@("`@("`@(&EF("$D14Y6
M>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O
M:3L*"B`@("`@("`@("`@("`@("`C($1O(&YO="!L970@6%-,;V%D97(@<&EC
M:R!U<"!A=71O+RH@9G)O;2!E;G9I<F]N;65N=`H@("`@("`@("`@("`@("`@
M)&-O;G1E;G0@/7X@<R]G;W1O("MR971R>2`K=6YL97-S("LN*B]G;W1O(')E
M=')Y.R\*("`@("`@("`@("`@("`@("`@("!I9B!L8R@D;F%M92D@97$@;&,H
M(EA33&]A9&5R+G!M(BD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&]U
M=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B`@("`@("`@("`@("1F:"T^
M<')I;G0H(D9)3$4B*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.
M)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN
M="AS<')I;G1F*`H@("`@("`@("`@("`@("`@(B4P.'@O)7,B+"!!<F-H:79E
M.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"B`@("`@("`@
M("`@("DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG
M=&@H)&-O;G1E;G0I*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H)&-O;G1E
M;G0I.PH@("`@("`@('T*("`@('T*("`@(",@?7U]"@H@("`@(R!.;W<@=W)I
M=&4@;W5T('1H92!005(@86YD(&UA9VEC('-T<FEN9W,@>WM["B`@("`D>FEP
M+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["@H@("`@)&-A8VAE
M7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PH@("`@:68@*"$D
M8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2![
M"B`@("`@("`@;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!
M.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*("`@("`@("`@("`@?'P@979A;"![
M(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@
M("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E
M<W0Z.DU$-2T^;F5W('T["@H@("`@("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G
M(&EN($1I9V5S=#HZ4TA!(#4N,S@@86YD(#4N,SD*("`@("`@("!M>2`D<VAA
M7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@
M,#L*("`@("`@("!I9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA
M7W9E<G-I;VX@97$@)S4N,SDG*2!["B`@("`@("`@("`@("1C='@M/F%D9&9I
M;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["B`@("`@("`@?0H@("`@("`@(&5L
M<V4@>PH@("`@("`@("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\
M)&]U="(I*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@
M("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@
M("!C;&]S92@D9F@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("`D8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I
M;64["B`@("!]"B`@("`D8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N
M9W1H("1C86-H95]N86UE*3L*("`@("1C86-H95]N86UE("X](")#04-(12([
M"B`@("`D9F@M/G!R:6YT*"1C86-H95]N86UE*3L*("`@("1F:"T^<')I;G0H
M<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PH@("`@
M)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I.PH@("`@)&9H+3YC;&]S93L*("`@
M(&-H;6]D(#`W-34L("1O=70["B`@("`C('U]?0H*("`@(&5X:70["GT*(R!]
M?7T*"B,@4')E<&%R92`D<')O9VYA;64@:6YT;R!005(@9FEL92!C86-H92![
M>WL*>PH@("`@;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PH*("`@
M(%]F:7A?<')O9VYA;64H*3L*"B`@("`C($YO=R!L;V%D('1H92!005(@9FEL
M92!A;F0@<'5T(&ET(&EN=&\@4$%2.CI,:6)#86-H92![>WL*("`@(')E<75I
M<F4@4$%2.PH@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*
M"B`@("!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%
M7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!R97%U:7)E($9I;&4Z
M.D9I;F0["B`@("`@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]"B`@
M("!M>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B`@("!M>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W.PH@("`@)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R
M)RD@;W(@9&EE("(D(3H@)$`B.PH@("`@)'II<"T^<F5A9$9R;VU&:6QE2&%N
M9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@
M;W(@9&EE("(D(3H@)$`B.PH*("`@('!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z
M:7`["B`@("`D4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*"B`@
M("`D<75I970@/2`A)$5.5GM005)?1$5"54=].PH@("`@;W5T<RAQ<2A<)$5.
M5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["@H@("`@:68@*&1E
M9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H
M:7,@<&]I;G0A"B`@("`@("`@9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^
M;65M8F5R<R`I('L*("`@("`@("`@("`@;F5X="!I9B`D;65M8F5R+3YI<T1I
M<F5C=&]R>3L*("`@("`@("`@("`@;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E
M<BT^9FEL94YA;64["B`@("`@("`@("`@(&YE>'0@=6YL97-S("1M96UB97)?
M;F%M92`]?B!M>PH@("`@("`@("`@("`@("`@7@H@("`@("`@("`@("`@("`@
M+S]S:&QI8B\*("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMV
M97)S:6]N?2\I/PH@("`@("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG
M>V%R8VAN86UE?2\I/PH@("`@("`@("`@("`@("`@*%M>+UTK*0H@("`@("`@
M("`@("`@("`@)`H@("`@("`@("`@("!]>#L*("`@("`@("`@("`@;7D@)&5X
M=')A8W1?;F%M92`]("0Q.PH@("`@("`@("`@("!M>2`D9&5S=%]N86UE(#T@
M1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?
M;F%M92D["B`@("`@("`@("`@(&EF("@M9B`D9&5S=%]N86UE("8F("US(%\@
M/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["B`@("`@("`@("`@
M("`@("!O=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET
M(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@;W5T<RAQ<2A%>'1R86-T:6YG
M("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@
M("`@("`@)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I
M.PH@("`@("`@("`@("`@("`@8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@
M)%Y/(&5Q(")H<'5X(CL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*
M("`@(",@?7U]"GT*(R!]?7T*"B,@268@=&AE<F4G<R!N;R!M86EN+G!L('1O
M(')U;BP@<VAO=R!U<V%G92![>WL*=6YL97-S("@D4$%2.CI,:6)#86-H97LD
M<')O9VYA;65]*2!["B`@("!D:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A
M9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;
M('-R8RYP87(@72!;('!R;V=R86TN<&P@70H@("`@("`@)#`@6R`M0GPM8B!=
M(%LM3V]U=&9I;&5=('-R8RYP87(*+@H@("`@)$5.5GM005)?4%)/1TY!345]
M(#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*(R!]?7T*"G-U
M8B!#<F5A=&50871H('L*("`@(&UY("@D;F%M92D@/2!`7SL*("`@(`H@("`@
M<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*("`@(&UY("@D8F%S96YA;64L("1P
M871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L
M("@G7"XN*B<I*3L*("`@(`H@("`@<F5Q=6ER92!&:6QE.CI0871H.PH@("`@
M"B`@("!&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T
M:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"@IS=6(@<F5Q=6ER95]M
M;V1U;&5S('L*("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?
M(&EF("1>3R!N92`G35-7:6XS,B<["@H@("`@<F5Q=6ER92!L:6(["B`@("!R
M97%U:7)E($1Y;F%,;V%D97(["B`@("!R97%U:7)E(&EN=&5G97(["B`@("!R
M97%U:7)E('-T<FEC=#L*("`@(')E<75I<F4@=V%R;FEN9W,["B`@("!R97%U
M:7)E('9A<G,["B`@("!R97%U:7)E($-A<G`["B`@("!R97%U:7)E($-A<G`Z
M.DAE879Y.PH@("`@<F5Q=6ER92!%<G)N;SL*("`@(')E<75I<F4@17AP;W)T
M97(Z.DAE879Y.PH@("`@<F5Q=6ER92!%>'!O<G1E<CL*("`@(')E<75I<F4@
M1F-N=&P["B`@("!R97%U:7)E($9I;&4Z.E1E;7`["B`@("!R97%U:7)E($9I
M;&4Z.E-P96,["B`@("!R97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER92!#
M;VYF:6<["B`@("!R97%U:7)E($E/.CI(86YD;&4["B`@("!R97%U:7)E($E/
M.CI&:6QE.PH@("`@<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*("`@(')E<75I
M<F4@07)C:&EV93HZ6FEP.PH@("`@<F5Q=6ER92!005(["B`@("!R97%U:7)E
M(%!!4CHZ2&5A=GD["B`@("!R97%U:7)E(%!!4CHZ1&ES=#L*("`@(')E<75I
M<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@<F5Q=6ER92!A='1R:6)U
M=&5S.PH@("`@979A;"![(')E<75I<F4@0W=D('T["B`@("!E=F%L('L@<F5Q
M=6ER92!7:6XS,B!].PH@("`@979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL
M('T["B`@("!E=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@
M?3L*("`@(&5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E
M('T["B`@("!E=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/
M.CIS8V%L87(@?3L*?0H*(R!4:&4@0R!V97)S:6]N(&]F('1H:7,@8V]D92!A
M<'!E87)S(&EN(&UY;&1R+VUK=&UP9&ER+F,*(R!4:&ES(&-O9&4@86QS;R!L
M:79E<R!I;B!005(Z.E-E='5P5&5M<"!A<R!S971?<&%R7W1E;7!?96YV(0IS
M=6(@7W-E=%]P87)?=&5M<"!["B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]4
M14U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B`@("`@("`@
M)'!A<E]T96UP(#T@)#$["B`@("`@("`@<F5T=7)N.PH@("`@?0H*("`@(&9O
M<F5A8V@@;7D@)'!A=&@@*`H@("`@("`@("AM87`@)$5.5GLD7WTL('%W*"!0
M05)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`H@("`@("`@
M('%W*"!#.EQ<5$5-4"`O=&UP("X@*0H@("`@*2!["B`@("`@("`@;F5X="!U
M;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H
M.PH@("`@("`@(&UY("1U<V5R;F%M93L*("`@("`@("!M>2`D<'=U:60["B`@
M("`@("`@(R!D;V5S(&YO="!W;W)K(&5V97)Y=VAE<F4Z"B`@("`@("`@979A
M;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PH*
M("`@("`@("!I9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PH@
M("`@("`@("`@("`D=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*("`@
M("`@("!]"B`@("`@("`@96QS:68@*&1E9FEN960@)'!W=6ED*2!["B`@("`@
M("`@("`@("1U<V5R;F%M92`]("1P=W5I9#L*("`@("`@("!]"B`@("`@("`@
M96QS92!["B`@("`@("`@("`@("1U<V5R;F%M92`]("1%3E9[55-%4DY!345]
M('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["B`@("`@("`@?0H@("`@("`@
M("1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*"B`@("`@("`@;7D@)'-T;7!D:7(@
M/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M)'5S97)N86UE(CL*("`@("`@
M("!M:V1I<B`D<W1M<&1I<BP@,#<U-3L*("`@("`@("!I9B`H(21%3E9[4$%2
M7T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI
M('L*("`@("`@("`@("`@;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M92D[
M"B`@("`@("`@("`@('-E96L@)&9H+"`M,3@L(#(["B`@("`@("`@("`@('-Y
M<W)E860@)&9H+"!M>2`D8G5F+"`V.PH@("`@("`@("`@("!I9B`H)&)U9B!E
M<2`B7#!#04-(12(I('L*("`@("`@("`@("`@("`@('-E96L@)&9H+"`M-3@L
M(#(["B`@("`@("`@("`@("`@("!S>7-R96%D("1F:"P@)&)U9BP@-#$["B`@
M("`@("`@("`@("`@("`D8G5F(#U^(',O7#`O+V<["B`@("`@("`@("`@("`@
M("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@
M("`@("!M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I
M9V5S=#HZ4TA!+3YN97<H,2D@?0H@("`@("`@("`@("`@("`@("`@('Q\(&5V
M86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@
M?0H@("`@("`@("`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S
M=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["@H@("`@("`@("`@("`@("`@
M(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@1&EG97-T.CI32$$@-2XS."!A;F0@
M-2XS.0H@("`@("`@("`@("`@("`@;7D@)'-H85]V97)S:6]N(#T@979A;"![
M("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["B`@("`@("`@("`@("`@
M("!I9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@
M97$@)S4N,SDG*2!["B`@("`@("`@("`@("`@("`@("`@)&-T>"T^861D9FEL
M92@D<')O9VYA;64L(")B(BD@:68@*"1C='@I.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1P<F]G;F%M92(I*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&-T>"T^861D9FEL92@D9F@I.PH@("`@("`@("`@
M("`@("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D<W1M<&1I
M<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M
M/FAE>&1I9V5S="`Z("1M=&EM92`I.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&-L;W-E*"1F:"D["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@
M("`@("`@("`D14Y6>U!!4E]#3$5!3GT@/2`Q.PH@("`@("`@("`@("`D<W1M
M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["B`@("`@("`@?0H*
M("`@("`@("`D14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PH@("`@("`@(&UK
M9&ER("1S=&UP9&ER+"`P-S4U.PH@("`@("`@(&QA<W0["B`@("!]"@H@("`@
M)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%2
M7U1%35!](#U^("\H+BLI+SL*?0H*<W5B(%]T96UP9FEL92!["B`@("!M>2`H
M)&5X="P@)&-R8RD@/2!`7SL*("`@(&UY("@D9F@L("1F:6QE;F%M92D["@H@
M("`@)&9I;&5N86UE(#T@(B1P87)?=&5M<"\D8W)C)&5X="(["@H@("`@:68@
M*"1%3E9[4$%27T-,14%.?2D@>PH@("`@("`@('5N;&EN:R`D9FEL96YA;64@
M:68@+64@)&9I;&5N86UE.PH@("`@("`@('!U<V@@0'1M<&9I;&4L("1F:6QE
M;F%M93L*("`@('T*("`@(&5L<V4@>PH@("`@("`@(')E='5R;B`H=6YD968L
M("1F:6QE;F%M92D@:68@*"UR("1F:6QE;F%M92D["B`@("!]"@H@("`@;W!E
M;B`D9F@L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*("`@(&)I;FUO9&4H
M)&9H*3L*("`@(')E='5R;B@D9F@L("1F:6QE;F%M92D["GT*"B,@<V%M92!C
M;V1E(&QI=F5S(&EN(%!!4CHZ4V5T=7!0<F]G;F%M93HZ<V5T7W!R;V=N86UE
M"G-U8B!?<V5T7W!R;V=N86UE('L*("`@(&EF("AD969I;F5D("1%3E9[4$%2
M7U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@
M>PH@("`@("`@("1P<F]G;F%M92`]("0Q.PH@("`@?0H*("`@("1P<F]G;F%M
M92!\?#T@)#`["@H@("`@:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D
M<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B`@("`@("`@)'!R
M;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@
M)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PH@("`@?0H*("`@(&EF("@A)$5.5GM0
M05)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L
M:6U]*2`^/2`P*2!["B`@("`@("`@:68@*&]P96X@;7D@)&9H+"`G/"<L("1P
M<F]G;F%M92D@>PH@("`@("`@("`@("!R971U<FX@:68@+7,@)&9H.PH@("`@
M("`@('T*("`@("`@("!I9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB
M*2!["B`@("`@("`@("`@("1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PH@
M("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H@("`@?0H*("`@(&9O<F5A
M8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%
M3E9[4$%42'TI('L*("`@("`@("!N97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]4
M14U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*("`@("`@("`D9&ER
M(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL*("`@("`@("`H*"1P<F]G
M;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?
M97AE?2(I+"!L87-T*0H@("`@("`@("`@("!I9B`M<R`B)&1I<B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PH@("`@("`@("@H)'!R
M;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S
M="D*("`@("`@("`@("`@:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O
M9VYA;64B.PH@("`@?0I]"@IS=6(@7V9I>%]P<F]G;F%M92!["B`@("`D,"`]
M("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PH@("`@:68@*&EN
M9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*("`@("`@
M("`D<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["B`@
M("!]"@H@("`@(R!86%@@+2!H86-K('1O(&UA:V4@4%=$('=O<FL*("`@(&UY
M("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H
M*0H@("`@("`@("`@("`@("`@.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I
M(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PH@("`@8VAO;7`H)'!W9"D[
M"B`@("`D<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM
M?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*"B`@("`D14Y6>U!!4E]04D]'
M3D%-17T@/2`D<')O9VYA;64["GT*"G-U8B!?<&%R7VEN:71?96YV('L*("`@
M(&EF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*("`@("`@
M("!R971U<FX["B`@("!](&5L<V4@>PH@("`@("`@("1%3E9[4$%27TE.251)
M04Q)6D5$?2`](#(["B`@("!]"@H@("`@9F]R("AQ=R@@4U!!5TY%1"!414U0
M($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%($%21T,@05)'5E\P("D@*2![
M"B`@("`@("`@9&5L971E("1%3E9[)U!!4E\G+B1??3L*("`@('T*("`@(&9O
M<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*("`@("`@("`D
M14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X
M:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PH@("`@?0H*("`@(&UY("1P
M87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B
M.PH*("`@(&EF("@D14Y6>U!!4E]414U0?2D@>PH@("`@("`@(&1E;&5T92`D
M14Y6>U!!4E]#3$5!3GT["B`@("!]"B`@("!E;'-I9B`H(65X:7-T<R`D14Y6
M>U!!4E]'3$]"04Q?0TQ%04Y]*2!["B`@("`@("`@;7D@)'9A;'5E(#T@<W5B
M<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*("`@("`@
M("`D14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%
M04X]*%Q3*RDO.PH@("`@?0I]"@IS=6(@;W5T<R!["B`@("!R971U<FX@:68@
M)'%U:65T.PH@("`@:68@*"1L;V=F:"D@>PH@("`@("`@('!R:6YT("1L;V=F
M:"`B0%]<;B(["B`@("!]"B`@("!E;'-E('L*("`@("`@("!P<FEN="`B0%]<
M;B(["B`@("!]"GT*"G-U8B!I;FET7VEN8R!["B`@("!R97%U:7)E($-O;F9I
M9SL*("`@('!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ
M0V]N9FEG>R1??2P@<7<H"B`@("`@("`@87)C:&QI8F5X<"!P<FEV;&EB97AP
M('-I=&5A<F-H97AP('-I=&5L:6)E>'`*("`@("`@("!V96YD;W)A<F-H97AP
M('9E;F1O<FQI8F5X<`H@("`@*3L*?0H*(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C"B,@5&AE(&UA:6X@<&%C:V%G92!F;W(@<V-R:7!T(&5X96-U=&EO
M;@H*<&%C:V%G92!M86EN.PH*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@
M7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PH*9&EE
M('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE
M(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0H@("`@=6YL97-S("UE
M("1P<F]G;F%M93L*"F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@
M*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PH*
M?3L*"B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0H*0T]213HZ97AI="@D,2D@
M:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@
M)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PH*,3L*"B-L:6YE(#$P,3(*"E]?
M14Y$7U\*`"1&<F5E0E-$.B!S<F,O;&EB+V-S=2]I,S@V+65L9B]C<G1N+E,L
M=B`Q+C8N,C(N,2XR+C$@,C`P.2\Q,"\R-2`P,3HQ,#HR.2!K96YS;6ET:"!%
M>'`@)```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````7`04(`````!AA!0C_____&`(%".E;`````````0``
M``$````!````'0(```$````G`@```0```#4"```!````0@(```\```"2`P``
M#````.B2!`@-````_/X$"`0````D@00(!0```-"*!`@&````4(0$"`H```#6
M!```"P```!`````5``````````,````@804(`@```-@!```4````$0```!<`
M```0D00($0```)B0!`@2````>````!,````(````_O__;WB0!`C___]O`0``
M`/#__V^FCP0(````````````````````````````````````````````````
M````````````````_____P````#_____```````````<8`4(```````````2
MDP0((I,$"#*3!`A"DP0(4I,$"&*3!`ARDP0(@I,$")*3!`BBDP0(LI,$",*3
M!`C2DP0(XI,$"/*3!`@"E`0($I0$""*4!`@RE`0(0I0$"%*4!`ABE`0(<I0$
M"(*4!`B2E`0(HI0$"+*4!`C"E`0(TI0$".*4!`CRE`0(`I4$"!*5!`@BE00(
M,I4$"$*5!`A2E00(8I4$"'*5!`B"E00(DI4$"**5!`BRE00(PI4$"-*5!`CB
ME00(\I4$"`*6!`@2E@0((I8$"#*6!`A"E@0(4I8$"&*6!`ARE@0(@I8$")*6
M!`BBE@0(LI8$"````````````"1&<F5E0E-$.B!S<F,O;&EB+V-S=2]C;VUM
M;VXO8W)T8G)A;F0N8RQV(#$N-BXR+C$N,BXQ(#(P,#DO,3`O,C4@,#$Z,3`Z
M,CD@:V5N<VUI=&@@17AP("0`)$9R965"4T0Z('-R8R]L:6(O8W-U+VDS.#8M
M96QF+V-R=#$N8RQV(#$N,34N,3`N,2XR+C$@,C`P.2\Q,"\R-2`P,3HQ,#HR
M.2!K96YS;6ET:"!%>'`@)`!'0T,Z("A'3E4I(#0N,BXQ(#(P,#<P-S$Y("!;
M1G)E94)31%T``$=#0SH@*$=.52D@-"XR+C$@,C`P-S`W,3D@(%M&<F5E0E-$
M70``1T-#.B`H1TY5*2`T+C(N,2`R,#`W,#<Q.2`@6T9R965"4T1=``!'0T,Z
M("A'3E4I(#0N,BXQ(#(P,#<P-S$Y("!;1G)E94)31%T``$=#0SH@*$=.52D@
M-"XR+C$@,C`P-S`W,3D@(%M&<F5E0E-$70``+G-H<W1R=&%B`"YI;G1E<G``
M+FYO=&4N04))+71A9P`N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S
M:6]N`"YG;G4N=F5R<VEO;E]R`"YR96PN9'EN`"YR96PN<&QT`"YI;FET`"YT
M97AT`"YF:6YI`"YR;V1A=&$`+F1A=&$`+F5H7V9R86UE`"YD>6YA;6EC`"YC
M=&]R<P`N9'1O<G,`+FIC<@`N9V]T`"YB<W,`+F-O;6UE;G0`````````````
M````````````````````````````````````````````"P````$````"````
M](`$"/0````5```````````````!`````````!,````'`````@````R!!`@,
M`0``&```````````````!``````````A````!0````(````D@00()`$``"P#
M```$``````````0````$````)P````L````"````4(0$"%`$``"`!@``!0``
M``$````$````$````"\````#`````@```-"*!`C0"@``U@0`````````````
M`0`````````W````____;P(```"FCP0(I@\``-`````$``````````(````"
M````1````/[__V\"````>)`$"'@0```@````!0````$````$`````````%,`
M```)`````@```)B0!`B8$```>`````0`````````!`````@```!<````"0``
M``(````0D00($!$``-@!```$````"P````0````(````90````$````&````
MZ)($".@2```1```````````````$`````````&`````!````!@```/R2!`C\
M$@``P`,`````````````!`````0```!K`````0````8```#`E@0(P!8``#QH
M`````````````!``````````<0````$````&````_/X$"/Q^```,````````
M```````$`````````'<````!`````@```"#_!`@@?P``0E\`````````````
M(`````````!_`````0````,`````8`4(`.```!@```````````````0`````
M````A0````$````"````&&`%"!C@```$```````````````$`````````(\`
M```&`````P```!Q@!0@<X```\`````4`````````!`````@```"8`````0``
M``,````,804(#.$```@```````````````0`````````GP````$````#````
M%&$%"!3A```(```````````````$`````````*8````!`````P```!QA!0@<
MX0``!```````````````!`````````"K`````0````,````@804((.$``/@`
M``````````````0````$````L`````@````#````(&(%""#B``"T!```````
M```````@`````````+4````!```````````````@X@``<`$`````````````
M`0`````````!`````P``````````````D.,``+X```````````````$`````
#````
